@@ -1,7 +1,7 @@
 #!/bin/bash
 
 #    This file is part of darktable.
-#    Copyright (C) 2016-2023 darktable developers.
+#    Copyright (C) 2016-2024 darktable developers.
 #
 #    darktable is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #   INSTALL_DIR - the installation prefix
 #   SRC_DIR - directory with the source code to be compiled
 #   CC, CXX, CFLAGS, CXXFLAGS are optional, but make sense for build
-#   TARGET - either build, skiptest, nofeatures or nofeatures_nosse
+#   TARGET - either build or skiptest
 #   ECO - some other flags for cmake
 
 set -ex
@@ -94,59 +94,6 @@ case "$TARGET" in
       $ECO "$SRC_DIR" || (cat "$BUILD_DIR"/CMakeFiles/CMakeOutput.log; cat "$BUILD_DIR"/CMakeFiles/CMakeError.log)
     target_notest
     ;;
-  "nofeatures")
-    cmake -DCMAKE_INSTALL_PREFIX="$INSTALL_PREFIX" \
-      -G"$GENERATOR" \
-      -DCMAKE_BUILD_TYPE="$CMAKE_BUILD_TYPE" \
-      -DUSE_OPENMP=OFF \
-      -DUSE_OPENCL=OFF \
-      -DUSE_LUA=OFF \
-      -DUSE_GAME=OFF \
-      -DUSE_CAMERA_SUPPORT=OFF \
-      -DUSE_NLS=OFF \
-      -DUSE_GRAPHICSMAGICK=OFF \
-      -DUSE_OPENJPEG=OFF \
-      -DUSE_JXL=OFF \
-      -DUSE_WEBP=OFF \
-      -DUSE_AVIF=OFF \
-      -DUSE_HEIF=OFF \
-      -DUSE_XCF=OFF \
-      -DBUILD_CMSTEST=OFF \
-      -DUSE_OPENEXR=OFF \
-      -DBUILD_PRINT=OFF \
-      -DBUILD_RS_IDENTIFY=OFF \
-      -DUSE_GMIC=OFF \
-      -DUSE_LIBSECRET=OFF \
-      $ECO "$SRC_DIR" || (cat "$BUILD_DIR"/CMakeFiles/CMakeOutput.log; cat "$BUILD_DIR"/CMakeFiles/CMakeError.log)
-    target_notest
-    ;;
-  "nofeatures_nosse")
-    cmake -DCMAKE_INSTALL_PREFIX="$INSTALL_PREFIX" \
-      -G"$GENERATOR" \
-      -DCMAKE_BUILD_TYPE="$CMAKE_BUILD_TYPE" \
-      -DUSE_OPENMP=OFF \
-      -DUSE_OPENCL=OFF \
-      -DUSE_LUA=OFF \
-      -DUSE_GAME=OFF \
-      -DUSE_CAMERA_SUPPORT=OFF \
-      -DUSE_NLS=OFF \
-      -DUSE_GRAPHICSMAGICK=OFF \
-      -DUSE_OPENJPEG=OFF \
-      -DUSE_JXL=OFF \
-      -DUSE_WEBP=OFF \
-      -DUSE_AVIF=OFF \
-      -DUSE_HEIF=OFF \
-      -DUSE_XCF=OFF \
-      -DBUILD_CMSTEST=OFF \
-      -DUSE_OPENEXR=OFF \
-      -DBUILD_PRINT=OFF \
-      -DBUILD_RS_IDENTIFY=OFF \
-      -DUSE_GMIC=OFF \
-      -DUSE_LIBSECRET=OFF \
-      -DBUILD_SSE2_CODEPATHS=OFF \
-      $ECO "$SRC_DIR" || (cat "$BUILD_DIR"/CMakeFiles/CMakeOutput.log; cat "$BUILD_DIR"/CMakeFiles/CMakeError.log)
-    target_notest
-    ;;
   *)
     exit 1
     ;;
