@@ -18,10 +18,6 @@
 
 #pragma once
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "common/darktable.h"
 
 G_BEGIN_DECLS
