@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2019-2023 darktable developers.
+    Copyright (C) 2019-2024 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -84,13 +84,7 @@ static inline void eigf_variance_analysis(const float *const restrict guide, //
   float maxg2 = 0.0f;
   float minmg = 10000000.0f;
   float maxmg = 0.0f;
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-dt_omp_firstprivate(guide, mask, in, Ndim) \
-  schedule(simd:static) \
-  reduction(max:maxg, maxm, maxg2, maxmg)\
-  reduction(min:ming, minm, ming2, minmg)
-#endif
+  DT_OMP_FOR(reduction(max:maxg, maxm, maxg2, maxmg) reduction(min:ming, minm, ming2, minmg))
   for(size_t k = 0; k < Ndim; k++)
   {
     const float pixelg = guide[k];
@@ -118,11 +112,7 @@ dt_omp_firstprivate(guide, mask, in, Ndim) \
   dt_gaussian_blur_4c(g, in, out);
   dt_gaussian_free(g);
 
-#ifdef _OPENMP
-#pragma omp parallel for simd default(none) \
-dt_omp_firstprivate(out, Ndim) \
-  schedule(simd:static) aligned(out:64)
-#endif
+  DT_OMP_FOR_SIMD(aligned(out:64))
   for(size_t k = 0; k < Ndim; k++)
   {
     out[4 * k + 1] -= out[4 * k] * out[4 * k];
@@ -147,13 +137,7 @@ static inline void eigf_variance_analysis_no_mask(const float *const restrict gu
   float maxg = 0.0f;
   float ming2 = 10000000.0f;
   float maxg2 = 0.0f;
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-dt_omp_firstprivate(guide, in, Ndim) \
-  schedule(simd:static) \
-  reduction(max:maxg, maxg2)\
-  reduction(min:ming, ming2)
-#endif
+  DT_OMP_FOR(reduction(max:maxg, maxg2) reduction(min:ming, ming2))
   for(size_t k = 0; k < Ndim; k++)
   {
     const float pixelg = guide[k];
@@ -173,11 +157,7 @@ dt_omp_firstprivate(guide, in, Ndim) \
   dt_gaussian_blur(g, in, out);
   dt_gaussian_free(g);
 
-#ifdef _OPENMP
-#pragma omp parallel for simd default(none) \
-dt_omp_firstprivate(out, Ndim) \
-  schedule(simd:static) aligned(out:64)
-#endif
+  DT_OMP_FOR_SIMD(aligned(out:64))
   for(size_t k = 0; k < Ndim; k++)
   {
     const float avg = out[2 * k];
@@ -192,11 +172,7 @@ void eigf_blending(float *const restrict image, const float *const restrict mask
                   const dt_iop_guided_filter_blending_t filter,
                   const float feathering)
 {
-#ifdef _OPENMP
-#pragma omp parallel for simd default(none) \
-  dt_omp_firstprivate(image, mask, av, Ndim, feathering, filter) \
-  schedule(simd:static) aligned(image, mask, av:64)
-#endif
+  DT_OMP_FOR()
   for(size_t k = 0; k < Ndim; k++)
   {
     const float avg_g = av[k * 4];
@@ -229,11 +205,7 @@ void eigf_blending_no_mask(float *const restrict image,
                   const dt_iop_guided_filter_blending_t filter,
                   const float feathering)
 {
-#ifdef _OPENMP
-#pragma omp parallel for simd default(none) \
-  dt_omp_firstprivate(image, av, Ndim, feathering, filter) \
-  schedule(simd:static) aligned(image, av:64)
-#endif
+  DT_OMP_FOR()
   for(size_t k = 0; k < Ndim; k++)
   {
     const float avg_g = av[k * 2];
@@ -323,11 +295,11 @@ static inline void fast_eigf_surface_blur(float *const restrict image,
   }
 
 clean:
-  if(av) dt_free_align(av);
-  if(ds_av) dt_free_align(ds_av);
-  if(ds_mask) dt_free_align(ds_mask);
-  if(ds_image) dt_free_align(ds_image);
-  if(mask) dt_free_align(mask);
+  dt_free_align(av);
+  dt_free_align(ds_av);
+  dt_free_align(ds_mask);
+  dt_free_align(ds_image);
+  dt_free_align(mask);
 }
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
