@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2010-2024 darktable developers.
+    Copyright (C) 2010-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,6 +53,12 @@ typedef struct dt_history_hash_values_t
   int current_len;
 } dt_history_hash_values_t;
 
+typedef enum dt_history_copy_mode_t
+{
+  DT_HISTORY_COPY_APPEND    = 0,
+  DT_HISTORY_COPY_OVERWRITE = 1
+} dt_history_copy_mode_t;
+
 typedef struct dt_history_copy_item_t
 {
   GList *selops;
@@ -60,6 +66,7 @@ typedef struct dt_history_copy_item_t
   dt_imgid_t copied_imageid;
   gboolean full_copy;
   gboolean copy_iop_order;
+  dt_history_copy_mode_t paste_mode;
 } dt_history_copy_item_t;
 
 /** helper function to free a GList of dt_history_item_t */
