@@ -1,6 +1,6 @@
 /*
  *    This file is part of darktable,
- *    Copyright (C) 2018-2024 darktable developers.
+ *    Copyright (C) 2018-2025 darktable developers.
  *
  *    darktable is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 
 #define LUT_ELEM 512 // gamut LUT number of elements:
 
+#define DT_MEGA 1048576lu
+
 #define NORM_MIN 1.52587890625e-05f // norm can't be < to 2^(-16)
 
 // select speed vs accuracy tradeoff
@@ -162,8 +164,8 @@ static inline float Log2Thres(const float x,
 // ensure that any changes here are synchronized with data/kernels/extended.cl
 static inline float fastlog2(const float x)
 {
-  union { float f; uint32_t i; } vx = { x };
-  union { uint32_t i; float f; } mx = { (vx.i & 0x007FFFFF) | 0x3f000000 };
+  const union { float f; uint32_t i; } vx = { x };
+  const union { uint32_t i; float f; } mx = { (vx.i & 0x007FFFFF) | 0x3f000000 };
 
   float y = vx.i;
 
@@ -294,8 +296,8 @@ static inline float median9f(const float *p)
   float p5 = MAX(p[4], p[5]);
   float p7 = MIN(p[7], p[8]);
   float p8 = MAX(p[7], p[8]);
-  float p0 = MIN(p[0], p1);
-  float p1a = MAX(p[0], p1);
+  const float p0 = MIN(p[0], p1);
+  const float p1a = MAX(p[0], p1);
   float p3 = MIN(p[3], p4);
   float p4a = MAX(p[3], p4);
   float p6 = MIN(p[6], p7);
@@ -683,8 +685,8 @@ static inline void dt_vector_div1(dt_aligned_pixel_t result,
 
 static inline float dt_vector_channel_max(const dt_aligned_pixel_t pixel)
 {
-  dt_aligned_pixel_t swapRG = { pixel[1], pixel[0], pixel[2], pixel[3] };
-  dt_aligned_pixel_t swapRB = { pixel[2], pixel[1], pixel[0], pixel[3] };
+  const dt_aligned_pixel_t swapRG = { pixel[1], pixel[0], pixel[2], pixel[3] };
+  const dt_aligned_pixel_t swapRB = { pixel[2], pixel[1], pixel[0], pixel[3] };
   dt_aligned_pixel_t maximum;
   for_each_channel(c)
     maximum[c] = MAX(MAX(pixel[c], swapRG[c]), swapRB[c]);
@@ -749,6 +751,30 @@ static inline void dt_vector_sin(const dt_aligned_pixel_t arg,
     sine[c] = scaled[c] * (p[c] * (abs_scaled[c] - one[c]) + one[c]);
 }
 
+// conversion factor, e.g.
+// dt_bauhaus_slider_set_factor(slider, RAD_2_DEG);
+static const double RAD_2_DEG = 180 / M_PI;
+
+static inline float deg2radf(const float deg)
+{
+  return deg * M_PI_F / 180.f;
+}
+
+static inline float rad2degf(const float radians)
+{
+  return radians / M_PI_F * 180.f;
+}
+
+static inline double deg2rad(const double deg)
+{
+  return deg * M_PI / 180.0;
+}
+
+static inline double rad2deg(const double radians)
+{
+  return radians / M_PI * 180.0;
+}
+
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
