@@ -177,7 +177,7 @@ GList *dt_tag_get_list_export(const dt_imgid_t imgid,
 /** get a flat list of only hierarchical tags, the difference to
  *  dt_tag_get_attached() is that this one filters out the
  *  "darktable|" tags. */
-GList *dt_tag_get_hierarchical(const dt_imgid_t imgid);
+GList *dt_tag_get_hierarchical(const dt_imgid_t imgid, const gboolean ignore_dt_tags);
 
 /** get a flat list of only hierarchical tags, the difference to
  *  dt_tag_get_hierarchical() is that this one checks option for
