@@ -36,6 +36,9 @@ GList *dt_control_crawler_run();
 // show a popup with the images, let the user decide what to do and free the list afterwards
 void dt_control_crawler_show_image_list(GList *images);
 
+// background thread updating all thumbnails is there is no user activity while being in lightroom
+void dt_update_thumbs_thread(void *ptr);
+void dt_set_backthumb_time(const double offset);
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
