@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2009-2024 darktable developers.
+    Copyright (C) 2009-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,13 +62,9 @@ typedef void (*dt_job_destroy_callback)(void *data);
 dt_job_t *dt_control_job_create(dt_job_execute_callback execute, const char *msg, ...) __attribute__((format(printf, 2, 3)));
 /** destroy a job object and free its memory. this does NOT remove it from any job queues! */
 void dt_control_job_dispose(dt_job_t *job);
-/** setup a state callback for job. */
-void dt_control_job_set_state_callback(dt_job_t *job, dt_job_state_change_callback cb);
 /** cancel a job, running or in queue. */
 void dt_control_job_cancel(dt_job_t *job);
 dt_job_state_t dt_control_job_get_state(dt_job_t *job);
-/** wait for a job to finish execution. */
-void dt_control_job_wait(dt_job_t *job);
 /** set job params and a callback to destroy those params */
 void dt_control_job_set_params(dt_job_t *job, void *params, dt_job_destroy_callback callback);
 /** set job params (with size params_size) and a callback to destroy those params.
@@ -78,23 +74,20 @@ void dt_control_job_set_params_with_size(dt_job_t *job, void *params, size_t par
 /** get job params. WARNING: you must not free them. dt_control_job_dispose() will take care of that */
 void *dt_control_job_get_params(const dt_job_t *job);
 
-void dt_control_job_add_progress(dt_job_t *job, const char *message, gboolean cancellable);
-void dt_control_job_set_progress_message(dt_job_t *job, const char *message);
-void dt_control_job_set_progress(dt_job_t *job, double value);
-double dt_control_job_get_progress(dt_job_t *job);
+void dt_control_job_add_progress(dt_job_t *job, const char *message, const gboolean cancellable);
+void dt_control_job_set_progress_message(dt_job_t *job, const char *message, ...);
+void dt_control_job_set_progress(dt_job_t *job, const double value);
+double dt_control_job_get_progress(const dt_job_t *job);
 
-struct dt_control_t;
-void dt_control_jobs_init(struct dt_control_t *control);
-void dt_control_jobs_cleanup(struct dt_control_t *control);
+void dt_control_jobs_init(void);
+void dt_control_jobs_cleanup(void);
+int dt_control_jobs_pending(void);
 
-gboolean dt_control_add_job(struct dt_control_t *control, dt_job_queue_t queue_id, dt_job_t *job);
-gboolean dt_control_add_job_res(struct dt_control_t *s, dt_job_t *job, int32_t res);
+gboolean dt_control_add_job(dt_job_queue_t queue_id, dt_job_t *job);
+gboolean dt_control_add_job_res(dt_job_t *job, const int32_t res);
 
 dt_view_type_flags_t dt_control_job_get_view_creator(const dt_job_t *job);
 gboolean dt_control_job_is_synchronous(const dt_job_t *job);
-void dt_control_job_set_synchronous(dt_job_t *job, gboolean sync);
-
-int32_t dt_control_get_threadid();
 
 #ifdef HAVE_GPHOTO2
 #include "control/jobs/camera_jobs.h"
