@@ -24,10 +24,10 @@
    When called from lightable : dev == NULL, in this case only the tags are imported
    When called from darkroom  : dev != NULL, in this case only develop data are imported
 */
-gboolean dt_lightroom_import(int imgid, dt_develop_t *dev, gboolean iauto);
+gboolean dt_lightroom_import(dt_imgid_t imgid, dt_develop_t *dev, gboolean iauto);
 
 /* returns NULL if not found, or g_strdup'ed pathname, the caller should g_free it. */
-char *dt_get_lightroom_xmp(int imgid);
+char *dt_get_lightroom_xmp(dt_imgid_t imgid);
 
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
