@@ -1,6 +1,6 @@
 /* -*- C++ -*-
  * File: libraw_types.h
- * Copyright 2008-2024 LibRaw LLC (info@libraw.org)
+ * Copyright 2008-2025 LibRaw LLC (info@libraw.org)
  * Created: Sat Mar  8 , 2008
  *
  * LibRaw C data structures
@@ -89,9 +89,19 @@ extern "C"
 #define NO_LCMS
 #endif
 
+#ifdef __cplusplus
+} /* extern C */
+#endif
+
+/* This cannot be in the extern C setting... */
 #include "libraw_const.h"
 #include "libraw_version.h"
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 #ifdef _WIN32
   typedef __int64 INT64;
   typedef unsigned __int64 UINT64;
@@ -235,6 +245,12 @@ typedef unsigned long long UINT64;
     float forwardmatrix[3][4];
   } libraw_dng_color_t;
 
+  typedef struct
+  {
+	  unsigned len;
+	  void *data;
+  } libraw_dng_rawopcode_t;
+
   typedef struct
   {
     unsigned parsedfields;
@@ -250,6 +266,7 @@ typedef unsigned long long UINT64;
     float asshotneutral[4];
     float baseline_exposure;
     float LinearResponseLimit;
+	libraw_dng_rawopcode_t rawopcodes[3];
   } libraw_dng_levels_t;
 
   typedef struct
@@ -292,6 +309,7 @@ typedef unsigned long long UINT64;
     int   AFMicroAdjMode;
     float AFMicroAdjValue;
     short MakernotesFlip;
+    short AutoRotateMode;
     short RecordMode;
     short SRAWQuality;
     unsigned wbi;
