@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2024 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2025 LibRaw LLC (info@libraw.org)
  *
  LibRaw uses code from dcraw.c -- Dave Coffin's raw photo decoder,
  dcraw.c is copyright 1997-2018 by Dave Coffin, dcoffin a cybercom o net.
@@ -152,7 +152,7 @@ void LibRaw::phase_one_flat_field(int is_float, int nc)
     for (x = 0; x < wide; x++)
       for (c = 0; c < (unsigned)nc; c += 2)
       {
-        num = is_float ? getreal(LIBRAW_EXIFTAG_TYPE_FLOAT) : get2() / 32768.0;
+        num = is_float ? getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT) : float(get2()) / 32768.f;
         if (y == 0)
           mrow[c * wide + x] = num;
         else
@@ -180,7 +180,7 @@ void LibRaw::phase_one_flat_field(int is_float, int nc)
           c = nc > 2 ? FC(row - top_margin, col - left_margin) : 0;
           if (!(c & 1))
           {
-            c = RAW(row, col) * mult[c];
+            c = unsigned(RAW(row, col) * mult[c]);
             RAW(row, col) = LIM(c, 0, 65535);
           }
           for (c = 0; c < (unsigned)nc; c += 2)
@@ -197,12 +197,14 @@ void LibRaw::phase_one_flat_field(int is_float, int nc)
 
 int LibRaw::phase_one_correct()
 {
-  unsigned entries, tag, data, save, col, row, type;
+  unsigned entries, tag, data, col, row, type;
+  INT64 save;
   int len, i, j, k, cip, sum;
 #if 0
   int val[4], dev[4], max;
 #endif
-  int head[9], diff, mindiff = INT_MAX, off_412 = 0;
+  int head[9], diff, mindiff = INT_MAX;
+  INT64 off_412 = 0;
   /* static */ const signed char dir[12][2] = {
       {-1, -1}, {-1, 1}, {1, -1},  {1, 1},  {-2, 0}, {0, -2},
       {0, 2},   {2, 0},  {-2, -2}, {-2, 2}, {2, -2}, {2, 2}};
@@ -219,6 +221,7 @@ int LibRaw::phase_one_correct()
   fseek(ifp, meta_offset + get4(), SEEK_SET);
   entries = get4();
   get4();
+  INT64 fsize = ifp->size();
 
   try
   {
@@ -238,6 +241,12 @@ int LibRaw::phase_one_correct()
 		  continue;
 	  }
 #endif
+      INT64 savepos = ftell(ifp);
+	  if (len < 0 || (len > 8 && savepos + (INT64)len > 2 * fsize))
+	  {
+        fseek(ifp, save, SEEK_SET); // Recover tiff-read position!!
+        continue;
+	  }
       if (tag == 0x0400)
       { /* Sensor defects */
         while ((len -= 8) >= 0)
@@ -298,24 +307,24 @@ int LibRaw::phase_one_correct()
       else if (tag == 0x0419)
       { /* Polynomial curve - output calibraion */
         for (get4(), i = 0; i < 8; i++)
-          poly[i] = getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+          poly[i] = getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         poly[3] += (ph1.tag_210 - poly[7]) * poly[6] + 1;
         for (i = 0; i < 0x10000; i++)
         {
           num = (poly[5] * i + poly[3]) * i + poly[1];
-          curve[i] = LIM(num, 0, 65535);
+          curve[i] = ushort(LIM(num, 0, 65535));
         }
         goto apply; /* apply to right half */
       }
       else if (tag == 0x041a)
       { /* Polynomial curve */
         for (i = 0; i < 4; i++)
-          poly[i] = getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+          poly[i] = getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         for (i = 0; i < 0x10000; i++)
         {
           for (num = 0, j = 4; j--;)
             num = num * i + poly[j];
-          curve[i] = LIM(num + i, 0, 65535);
+          curve[i] = ushort(LIM(num + i, 0, 65535));
         }
       apply: /* apply to whole image */
         for (row = 0; row < raw_height; row++)
@@ -348,7 +357,8 @@ int LibRaw::phase_one_correct()
           off_412 = ftell(ifp) - 38;
         }
       }
-      else if (tag == 0x041f && !qlin_applied)
+      else if (tag == 0x041f && !qlin_applied && ph1.split_col > 0 && ph1.split_col < raw_width
+		&& ph1.split_row > 0 && ph1.split_row < raw_height)
       { /* Quadrant linearization */
         ushort lc[2][2][16], ref[16];
         int qr, qc;
@@ -405,34 +415,35 @@ int LibRaw::phase_one_correct()
         get4();
         get4();
         get4();
-        qmult[0][0] = 1.0 + getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+        qmult[0][0] = 1.0f + getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         get4();
         get4();
         get4();
         get4();
         get4();
-        qmult[0][1] = 1.0 + getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+        qmult[0][1] = 1.0f + getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         get4();
         get4();
         get4();
-        qmult[1][0] = 1.0 + getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+        qmult[1][0] = 1.0f + getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         get4();
         get4();
         get4();
-        qmult[1][1] = 1.0 + getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+        qmult[1][1] = 1.0f + getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
         for (row = 0; row < raw_height; row++)
         {
           checkCancel();
           for (col = 0; col < raw_width; col++)
           {
-            i = qmult[row >= (unsigned)ph1.split_row][col >= (unsigned)ph1.split_col] *
-                RAW(row, col);
+            i = int(qmult[row >= (unsigned)ph1.split_row][col >= (unsigned)ph1.split_col] *
+                RAW(row, col));
             RAW(row, col) = LIM(i, 0, 65535);
           }
         }
         qmult_applied = 1;
       }
-      else if (tag == 0x0431 && !qmult_applied)
+      else if (tag == 0x0431 && !qmult_applied && ph1.split_col > 0 && ph1.split_col < raw_width 
+		&& ph1.split_row > 0 && ph1.split_row < raw_height)
       { /* Quadrant combined - four tile gain calibration */
         ushort lc[2][2][7], ref[7];
         int qr, qc;
@@ -490,6 +501,11 @@ int LibRaw::phase_one_correct()
       fseek(ifp, off_412, SEEK_SET);
       for (i = 0; i < 9; i++)
         head[i] = get4() & 0x7fff;
+	  unsigned w0 = head[1] * head[3], w1 = head[2] * head[4];
+	  if (w0 > 10240000 || w1 > 10240000)
+		  throw LIBRAW_EXCEPTION_ALLOC;
+	  if (w0 < 1 || w1 < 1)
+		  throw LIBRAW_EXCEPTION_IO_CORRUPT;
       yval[0] = (float *)calloc(head[1] * head[3] + head[2] * head[4], 6);
       yval[1] = (float *)(yval[0] + head[1] * head[3]);
       xval[0] = (ushort *)(yval[1] + head[2] * head[4]);
@@ -497,7 +513,7 @@ int LibRaw::phase_one_correct()
       get2();
       for (i = 0; i < 2; i++)
         for (j = 0; j < head[i + 1] * head[i + 3]; j++)
-          yval[i][j] = getreal(LIBRAW_EXIFTAG_TYPE_FLOAT);
+          yval[i][j] = getrealf(LIBRAW_EXIFTAG_TYPE_FLOAT);
       for (i = 0; i < 2; i++)
         for (j = 0; j < head[i + 1] * head[i + 3]; j++)
           xval[i][j] = get2();
@@ -507,19 +523,27 @@ int LibRaw::phase_one_correct()
         for (col = 0; col < raw_width; col++)
         {
           cfrac = (float)col * head[3] / raw_width;
-          cfrac -= cip = cfrac;
-          num = RAW(row, col) * 0.5;
+		  cip = (int)cfrac;
+          cfrac -= cip;
+          num = RAW(row, col) * 0.5f;
           for (i = cip; i < cip + 2; i++)
           {
             for (k = j = 0; j < head[1]; j++)
               if (num < xval[0][k = head[1] * i + j])
                 break;
-            frac = (j == 0 || j == head[1])
-                       ? 0
-                       : (xval[0][k] - num) / (xval[0][k] - xval[0][k - 1]);
-            mult[i - cip] = yval[0][k - 1] * frac + yval[0][k] * (1 - frac);
+			if (j == 0 || j == head[1] || k < 1 || k >= w0+w1)
+				frac = 0;
+			else
+			{
+				int xdiv = (xval[0][k] - xval[0][k - 1]);
+				frac = xdiv ? (xval[0][k] - num) / (xval[0][k] - xval[0][k - 1]) : 0;
+			}
+			if (k < w0 + w1)
+				mult[i - cip] = yval[0][k > 0 ? k - 1 : 0] * frac + yval[0][k] * (1 - frac);
+			else
+				mult[i - cip] = 0;
           }
-          i = ((mult[0] * (1 - cfrac) + mult[1] * cfrac) * row + num) * 2;
+          i = int(((mult[0] * (1.f - cfrac) + mult[1] * cfrac) * row + num) * 2.f);
           RAW(row, col) = LIM(i, 0, 65535);
         }
       }
@@ -585,7 +609,10 @@ unsigned LibRaw::ph1_bithuff(int nbits, ushort *huff)
   unsigned c;
 
   if (nbits == -1)
-    return bitbuf = vbits = 0;
+  {
+	  bitbuf = vbits = 0;
+	  return 0;
+  }
   if (nbits == 0)
     return 0;
   if (vbits < nbits)
@@ -593,7 +620,7 @@ unsigned LibRaw::ph1_bithuff(int nbits, ushort *huff)
     bitbuf = bitbuf << 32 | get4();
     vbits += 32;
   }
-  c = bitbuf << (64 - vbits) >> (64 - nbits);
+  c = unsigned ((bitbuf << (64 - vbits) >> (64 - nbits)) & 0xffffffff);
   if (huff)
   {
     vbits -= huff[c] >> 8;
@@ -644,7 +671,7 @@ void LibRaw::phase_one_load_raw_c()
   }
 
   for (i = 0; i < 256; i++)
-    curve[i] = i * i / 3.969 + 0.5;
+    curve[i] = ushort(float(i * i) / 3.969f + 0.5f);
   try
   {
     for (row = 0; row < raw_height; row++)
