@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2021 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2025 LibRaw LLC (info@libraw.org)
  *
  LibRaw is free software; you can redistribute it and/or modify
  it under the terms of the one of two licenses as you choose:
@@ -49,8 +49,16 @@ int LibRaw::unpack(void)
     }
     if (libraw_internal_data.unpacker_data.meta_length)
     {
+      if (libraw_internal_data.unpacker_data.meta_length >
+          INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
+        throw LIBRAW_EXCEPTION_TOOBIG;
+
       libraw_internal_data.internal_data.meta_data =
+#ifdef LIBRAW_CALLOC_RAWSTORE
+          (char *)calloc(libraw_internal_data.unpacker_data.meta_length,1);
+#else
           (char *)malloc(libraw_internal_data.unpacker_data.meta_length);
+#endif
     }
 
     libraw_decoder_info_t decoder_info;
@@ -90,7 +98,8 @@ int LibRaw::unpack(void)
           (imgdata.idata.filters || P1.colors == 1) ? 1 : LIM(P1.colors, 3, 4);
       INT64 samplesize = is_floating_point() ? 4 : 2;
       INT64 bytes = pixcount * planecount * samplesize;
-      if (bytes > INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
+      if (bytes + INT64(libraw_internal_data.unpacker_data.meta_length )
+			> INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
         throw LIBRAW_EXCEPTION_TOOBIG;
 
       // find ifd to check sample
@@ -101,6 +110,7 @@ int LibRaw::unpack(void)
 #endif
 #ifdef USE_RAWSPEED3
     if (!raw_was_read()
+		&& ID.input->size() < 2147483615LL
         && (!IO.fuji_width) // Do not use for fuji rotated
         && ((imgdata.idata.raw_count == 1) 
             // Canon dual pixel, 1st frame
@@ -117,7 +127,8 @@ int LibRaw::unpack(void)
       INT64 pixcount = INT64(MAX(S.width, S.raw_width)) * INT64(MAX(S.height, S.raw_height));
       INT64 planecount = (imgdata.idata.filters || P1.colors == 1) ? 1 : LIM(P1.colors, 3, 4);
       INT64 bytes = pixcount * planecount * 2; // sample size is always 2 for rawspeed
-      if (bytes > INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
+      if (bytes + INT64(libraw_internal_data.unpacker_data.meta_length) 
+				> INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
         throw LIBRAW_EXCEPTION_TOOBIG;
 
         if (!_rawspeed3_handle)
@@ -161,9 +172,7 @@ int LibRaw::unpack(void)
                       throw "Size mismatch";
 
                     // DECODED w/ success
-                  if (rs3ret.filters>1) // Fuji or bayer
-                      imgdata.rawdata.raw_image = (ushort*)rs3ret.pixeldata;
-                  else if (rs3ret.cpp == 4)
+                  if (rs3ret.cpp == 4)
                   {
                       imgdata.rawdata.color4_image = (ushort(*)[4])rs3ret.pixeldata;
                     //if (r->whitePoint > 0 && r->whitePoint < 65536)
@@ -175,6 +184,10 @@ int LibRaw::unpack(void)
                     //if (r->whitePoint > 0 && r->whitePoint < 65536)
                     //  C.maximum = r->whitePoint;
                   }
+                  else if (rs3ret.cpp == 1 && rs3ret.filters > 1) // Fuji or bayer
+                  {
+                    imgdata.rawdata.raw_image = (ushort *)rs3ret.pixeldata;
+                  }
 
                   if (raw_was_read()) // buffers are assigned above
                   {
@@ -183,6 +196,16 @@ int LibRaw::unpack(void)
                     S.raw_width = rs3ret.width;
                     S.raw_height = rs3ret.height;
                     imgdata.process_warnings |= LIBRAW_WARN_RAWSPEED3_PROCESSED;
+
+					if (imgdata.rawdata.raw_image && 
+						load_raw == &LibRaw::phase_one_load_raw_c && imgdata.color.phase_one_data.format != 8)
+                    {
+                      // Scale data to match libraw own decoder
+                      for (unsigned row = 0; row < rs3ret.height; row++)
+                        for (unsigned col = 0; col < rs3ret.pitch / 2; col++)
+                          imgdata.rawdata.raw_image[row * rs3ret.pitch / 2 + col] <<= 2;
+                    }
+
                     // if (r->whitePoint > 0 && r->whitePoint < 65536)
                     // C.maximum = r->whitePoint;
                   }
@@ -199,7 +222,7 @@ int LibRaw::unpack(void)
     }
 #endif
 #ifdef USE_RAWSPEED
-    if (!raw_was_read())
+    if (!raw_was_read() && ID.input->size() < 2147483615LL)
     {
       int rawspeed_enabled = 1;
 
@@ -280,7 +303,7 @@ int LibRaw::unpack(void)
                                : LIM(P1.colors, 3, 4);
         INT64 bytes =
             pixcount * planecount * 2; // sample size is always 2 for rawspeed
-        if (bytes >
+        if (bytes + +INT64(libraw_internal_data.unpacker_data.meta_length) >
             INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
           throw LIBRAW_EXCEPTION_TOOBIG;
 
@@ -303,11 +326,16 @@ int LibRaw::unpack(void)
         if (imgdata.rawparams.shot_select) // single image extract
         {
           if (INT64(rwidth) * INT64(rheight + 8) *
-                  INT64(sizeof(imgdata.rawdata.raw_image[0])) >
+                  INT64(sizeof(imgdata.rawdata.raw_image[0])) 
+				+ +INT64(libraw_internal_data.unpacker_data.meta_length) >
               INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
             throw LIBRAW_EXCEPTION_TOOBIG;
+#ifdef LIBRAW_CALLOC_RAWSTORE
+          imgdata.rawdata.raw_alloc = calloc(size_t(rwidth) * (size_t(rheight) + 8), sizeof(imgdata.rawdata.raw_image[0]));
+#else
           imgdata.rawdata.raw_alloc = malloc(
-              rwidth * (rheight + 8) * sizeof(imgdata.rawdata.raw_image[0]));
+              size_t(rwidth) * (size_t(rheight) + 8) * sizeof(imgdata.rawdata.raw_image[0]));
+#endif
           imgdata.rawdata.raw_image = (ushort *)imgdata.rawdata.raw_alloc;
           if (!S.raw_pitch)
             S.raw_pitch = S.raw_width * 2; // Bayer case, not set before
@@ -315,26 +343,38 @@ int LibRaw::unpack(void)
         else // Full image extract
         {
           if (INT64(rwidth) * INT64(rheight + 8) *
-                  INT64(sizeof(imgdata.rawdata.raw_image[0])) * 4 >
+                  INT64(sizeof(imgdata.rawdata.raw_image[0])) * 4 
+				+INT64(libraw_internal_data.unpacker_data.meta_length) >
               INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
             throw LIBRAW_EXCEPTION_TOOBIG;
           S.raw_pitch = S.raw_width * 8;
           imgdata.rawdata.raw_alloc = 0;
+#ifdef LIBRAW_CALLOC_RAWSTORE
           imgdata.image = (ushort(*)[4])calloc(
-              unsigned(MAX(S.width, S.raw_width)) *
-                  unsigned(MAX(S.height, S.raw_height) + 8),
+              size_t(MAX(S.width, S.raw_width)) *
+                  (size_t(MAX(S.height, S.raw_height)) + 8),
               sizeof(*imgdata.image));
+#else
+          imgdata.image = (ushort(*)[4])malloc(
+              size_t(MAX(S.width, S.raw_width)) * (size_t(MAX(S.height, S.raw_height)) + 8) * sizeof(*imgdata.image));
+#endif
         }
       }
       else if (decoder_info.decoder_flags & LIBRAW_DECODER_3CHANNEL)
       {
         if (INT64(rwidth) * INT64(rheight + 8) *
-                INT64(sizeof(imgdata.rawdata.raw_image[0])) * 3 >
+                INT64(sizeof(imgdata.rawdata.raw_image[0])) * 3 
+			+ INT64(libraw_internal_data.unpacker_data.meta_length) >
             INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
           throw LIBRAW_EXCEPTION_TOOBIG;
 
+#ifdef LIBRAW_CALLOC_RAWSTORE
+        imgdata.rawdata.raw_alloc =
+            calloc(size_t(rwidth) * (size_t(rheight) + 8), sizeof(imgdata.rawdata.raw_image[0]) * 3);
+#else
         imgdata.rawdata.raw_alloc = malloc(
-            rwidth * (rheight + 8) * sizeof(imgdata.rawdata.raw_image[0]) * 3);
+            size_t(rwidth) * (size_t(rheight) + 8) * sizeof(imgdata.rawdata.raw_image[0]) * 3);
+#endif
         imgdata.rawdata.color3_image = (ushort(*)[3])imgdata.rawdata.raw_alloc;
         if (!S.raw_pitch)
           S.raw_pitch = S.raw_width * 6;
@@ -344,11 +384,17 @@ int LibRaw::unpack(void)
                    1) // Bayer image or single color -> decode to raw_image
       {
         if (INT64(rwidth) * INT64(rheight + 8) *
-                INT64(sizeof(imgdata.rawdata.raw_image[0])) >
+                INT64(sizeof(imgdata.rawdata.raw_image[0])) 
+			+ INT64(libraw_internal_data.unpacker_data.meta_length) >
             INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
           throw LIBRAW_EXCEPTION_TOOBIG;
+#ifdef LIBRAW_CALLOC_RAWSTORE
+        imgdata.rawdata.raw_alloc =
+            calloc(size_t(rwidth) * (size_t(rheight) + 8),sizeof(imgdata.rawdata.raw_image[0]));
+#else
         imgdata.rawdata.raw_alloc = malloc(
-            rwidth * (rheight + 8) * sizeof(imgdata.rawdata.raw_image[0]));
+            size_t(rwidth) * (size_t(rheight) + 8) * sizeof(imgdata.rawdata.raw_image[0]));
+#endif
         imgdata.rawdata.raw_image = (ushort *)imgdata.rawdata.raw_alloc;
         if (!S.raw_pitch)
           S.raw_pitch = S.raw_width * 2; // Bayer case, not set before
@@ -375,7 +421,8 @@ int LibRaw::unpack(void)
         // allocate image as temporary buffer, size
         if (INT64(MAX(S.width, S.raw_width)) *
                 INT64(MAX(S.height, S.raw_height) + 8) *
-                INT64(sizeof(*imgdata.image)) >
+                INT64(sizeof(*imgdata.image)) 
+			+ INT64(libraw_internal_data.unpacker_data.meta_length) >
             INT64(imgdata.rawparams.max_raw_memory_mb) * INT64(1024 * 1024))
           throw LIBRAW_EXCEPTION_TOOBIG;
 
