@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2024 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2025 LibRaw LLC (info@libraw.org)
  *
  LibRaw is free software; you can redistribute it and/or modify
  it under the terms of the one of two licenses as you choose:
@@ -68,7 +68,7 @@ void LibRaw::setLeicaBodyFeatures(int LeicaMakernoteSignature)
   }
   else if ((LeicaMakernoteSignature == 0x0600) || // "T (Typ 701)", TL
            (LeicaMakernoteSignature == 0x0900) || // SL2, "SL2-S", "SL (Typ 601)", CL, Q2, "Q2 MONO"
-           (LeicaMakernoteSignature == 0x0a00) || // Q3
+           (LeicaMakernoteSignature == 0x0a00) || // Q3, "Q3 43", SL3
            (LeicaMakernoteSignature == 0x1a00))   // TL2
   {
     if ((model[0] == 'S') || (model[6] == 'S'))
@@ -177,11 +177,12 @@ non_std:
   return 1;
 }
 
-void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
+void LibRaw::parseLeicaMakernote(INT64 base, int uptag, unsigned MakernoteTagType)
 {
   int c;
   uchar ci, cj;
-  unsigned entries, tag, type, len, save;
+  unsigned entries, tag, type, len;
+  INT64 save;
   short morder, sorder = order;
   char buf[10];
   int LeicaMakernoteSignature = -1;
@@ -200,7 +201,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
   {
     fseek(ifp, -2, SEEK_CUR);
     LeicaMakernoteSignature = ((uchar)buf[6] << 8) | (uchar)buf[7];
-    // printf ("LeicaMakernoteSignature 0x%04x\n", LeicaMakernoteSignature);
+// printf ("LeicaMakernoteSignature 0x%04x\n", LeicaMakernoteSignature);
     if (!LeicaMakernoteSignature &&
         (!strncmp(model, "M8", 2) || !strncmp(model + 6, "M8", 2)))
       LeicaMakernoteSignature = -3;
@@ -234,6 +235,13 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
     if (len > 100 * 1024 * 1024)
       goto next; // 100Mb tag? No!
 
+	if (callbacks.makernotes_cb)
+    {
+      INT64 _savepos = ifp->tell();
+      callbacks.makernotes_cb(callbacks.makernotesparser_data, tag, type, len, order, ifp, base);
+      fseek(ifp, _savepos, SEEK_SET);
+    }
+
     if (LeicaMakernoteSignature == -3) // M8
     {
       if (tag == 0x0310)
@@ -242,7 +250,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
       }
       else if ((tag == 0x0313) && (fabs(ilm.CurAp) < 0.17f))
       {
-        ilm.CurAp = getreal(type);
+        ilm.CurAp = getrealf(type);
         if (ilm.CurAp > 126.3)
         {
           ilm.CurAp = 0.0f;
@@ -251,7 +259,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
       }
       else if (tag == 0x0320)
       {
-        imCommon.CameraTemperature = getreal(type);
+        imCommon.CameraTemperature = getrealf(type);
       }
     }
     else if (LeicaMakernoteSignature == -2) // DMR
@@ -336,7 +344,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
     else if ((LeicaMakernoteSignature == 0x0800) || // "Q (Typ 116)"
              (LeicaMakernoteSignature == 0x0900) || // SL2, "SL2-S", "SL (Typ 601)",
                                                     // CL, Q2, "Q2 MONO"
-             (LeicaMakernoteSignature == 0x0a00)    // Q3
+             (LeicaMakernoteSignature == 0x0a00)    // Q3, "Q3 43", SL3
             )
     {
       if ((tag == 0x0304) && (len == 1) && ((c = fgetc(ifp)) != 0) &&
@@ -356,7 +364,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
     {
       if (tag == 0x34003402)
       {
-        imCommon.CameraTemperature = getreal(type);
+        imCommon.CameraTemperature = getrealf(type);
       }
       else if (tag == 0x34003405)
       {
@@ -364,7 +372,7 @@ void LibRaw::parseLeicaMakernote(int base, int uptag, unsigned MakernoteTagType)
       }
       else if ((tag == 0x34003406) && (fabs(ilm.CurAp) < 0.17f))
       {
-        ilm.CurAp = getreal(type);
+        ilm.CurAp = getrealf(type);
         if (ilm.CurAp > 126.3)
         {
           ilm.CurAp = 0.0f;
