@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2024 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2025 LibRaw LLC (info@libraw.org)
  *
  LibRaw is free software; you can redistribute it and/or modify
  it under the terms of the one of two licenses as you choose:
@@ -32,6 +32,13 @@ static const char *static_camera_list[] = {
 	"Apple iPhone 12 Pro Max",
 	"Apple iPhone 13",
 	"Apple iPhone 14",
+	"Apple iPhone 14 Plus",
+	"Apple iPhone 14 Pro",
+	"Apple iPhone 14 Pro Max",
+	"Apple iPhone 15",
+	"Apple iPhone 15 Plus",
+	"Apple iPhone 15 Pro",
+	"Apple iPhone 15 Pro Max",
 	"Apple QuickTake 100",
 	"Apple QuickTake 150",
 	"Apple QuickTake 200",
@@ -144,8 +151,11 @@ static const char *static_camera_list[] = {
 	"Canon EOS R",
 	"Canon EOS Ra",
 	"Canon EOS RP",
+	"Canon EOS R1",
 	"Canon EOS R3",
 	"Canon EOS R5",
+	"Canon EOS R5 C",
+	"Canon EOS R5 Mark II",
 	"Canon EOS R6",
 	"Canon EOS R6 Mark II",
 	"Canon EOS R7",
@@ -342,6 +352,7 @@ static const char *static_camera_list[] = {
 	"FujiFilm GFX 100",
 	"FujiFilm GFX 100 II",
 	"FujiFilm GFX 100S",
+	"FujiFilm GFX 100S II",
 	"FujiFilm X-Pro1",
 	"FujiFilm X-Pro2",
 	"FujiFilm X-Pro3",
@@ -354,6 +365,7 @@ static const char *static_camera_list[] = {
 	"FujiFilm X100S",
 	"FujiFilm X100T",
 	"FujiFilm X100V",
+	"FujiFilm X100VI",
 	"FujiFilm X10",
 	"FujiFilm X20",
 	"FujiFilm X30",
@@ -387,6 +399,7 @@ static const char *static_camera_list[] = {
 	"FujiFilm X-T20",
 	"FujiFilm X-T30",
 	"FujiFilm X-T30 II",
+	"FujiFilm X-T50",
 	"FujiFilm X-T100",
 	"FujiFilm X-T200",
 	"FujiFilm IS-1",
@@ -401,6 +414,10 @@ static const char *static_camera_list[] = {
 	"Google Pixel 4a (5G)",
 	"Google Pixel 5",
 	"Google Pixel 7a",
+	"Google Pixel 8 Pro",
+	"Google Pixel 9 Pro",
+	"Google Pixel 9 Pro XL",
+	"Google Pixel 9 Pro Fold",
 #ifdef  USE_GPRSDK
 	"GoPro Fusion",
 	"GoPro HERO5",
@@ -433,7 +450,9 @@ static const char *static_camera_list[] = {
 	"Hasselblad A6D-100c", // Aerial camera
 	"Hasselblad CFV",
 	"Hasselblad CFV-50",
+	"Hasselblad CFV-50c",
 	"Hasselblad CFV II 50C",
+	"Hasselblad CFV-100c",
 	"Hasselblad CFH",
 	"Hasselblad CF-22",
 	"Hasselblad CF-31",
@@ -499,7 +518,6 @@ static const char *static_camera_list[] = {
 	"Kodak DCS420",
 	"Kodak DCS460",
 	"Kodak DCS460M",
-	"Kodak DCS460",
 	"Kodak DCS520C",
 	"Kodak DCS560C",
 	"Kodak DCS620C",
@@ -583,6 +601,7 @@ static const char *static_camera_list[] = {
 	"Leica D-LUX5",
 	"Leica D-LUX6",
 	"Leica D-LUX7",
+	"Leica D-Lux8",
 	"Leica D-Lux (Typ 109)",
 	"Leica M8",
 	"Leica M8.2",
@@ -607,6 +626,7 @@ static const char *static_camera_list[] = {
 	"Leica Q2",
 	"Leica Q2 Monochrom",
 	"Leica Q3",
+	"Leica Q3 43",
 	"Leica S",
 	"Leica S2",
 	"Leica S3",
@@ -614,6 +634,7 @@ static const char *static_camera_list[] = {
 	"Leica SL (Typ 601)",
 	"Leica SL2",
 	"Leica SL2-S",
+	"Leica SL3",
 	"Leica T (Typ 701)",
 	"Leica TL",
 	"Leica TL2",
@@ -716,12 +737,14 @@ static const char *static_camera_list[] = {
 	"Nikon Z 5",
 	"Nikon Z 6",
 	"Nikon Z 6 II",
+	"Nikon Z 6 III (HE/HE* formats are not supported yet)",
 	"Nikon Z 7",
 	"Nikon Z 7 II",
 	"Nikon Z 8 (HE/HE* formats are not supported yet)",
 	"Nikon Z 9 (HE/HE* formats are not supported yet)",
 	"Nikon Z 30",
 	"Nikon Z 50",
+	"Nikon Z f (HE/HE* formats are not supported yet)",
 	"Nikon Z fc",
 	"Nikon 1 AW1",
 	"Nikon 1 J1",
@@ -849,10 +872,12 @@ static const char *static_camera_list[] = {
 	"Olympus TG-4",
 	"Olympus TG-5",
 	"Olympus TG-6",
+	"Olympus TG-7",
 	"Olympus XZ-1",
 	"Olympus XZ-2",
 	"Olympus XZ-10",
 	"OM Digital Solutions OM-1",
+	"OM Digital Solutions OM-1 Mark II",
 	"OM Digital Solutions OM-5",
 	"OmniVision 4688",
 	"OmniVision OV5647",
@@ -912,6 +937,7 @@ static const char *static_camera_list[] = {
 	"Panasonic DC-GH5S",
 	"Panasonic DC-GH5 Mark II",
 	"Panasonic DC-GH6",
+	"Panasonic DC-GH7",
 	"Panasonic DMC-GM1",
 	"Panasonic DMC-GM1s",
 	"Panasonic DMC-GM5",
@@ -938,6 +964,7 @@ static const char *static_camera_list[] = {
 	"Panasonic DC-S1R",
 	"Panasonic DC-S5",
 	"Panasonic DC-S5 MkII",
+	"Panasonic DC-S9",
 	"Panasonic DMC-ZS40, DMC-TZ60 / TZ61",
 	"Panasonic DMC-ZS50, DMC-TZ70 / TZ71",
 	"Panasonic DMC-ZS60, DMC-TZ80 / TZ81 / TZ82 / TZ85",
@@ -961,6 +988,7 @@ static const char *static_camera_list[] = {
 	"Pentax K110D",
 	"Pentax K200D",
 	"Pentax K2000/K-m",
+	"Pentax KF",
 	"Pentax KP",
 	"Pentax K-x",
 	"Pentax K-r",
@@ -970,7 +998,7 @@ static const char *static_camera_list[] = {
 	"Pentax K-3",
 	"Pentax K-3 Mark II",
 	"Pentax K-3 Mark III",
-//	"Pentax K-3 Mark III Monochrome",
+	"Pentax K-3 Mark III Monochrome",
 	"Pentax K-30",
 	"Pentax K-5",
 	"Pentax K-5 II",
@@ -1072,6 +1100,8 @@ static const char *static_camera_list[] = {
 	"Samsung Galaxy S10 (SM-G973F)",
 	"Samsung Galaxy S10+ (SM-G975U)",
 	"Samsung Galaxy S22 Ultra (SM-S908B)",
+	"Samsung Galaxy S23+",
+	"Samsung Galaxy S23 Ultra",
 	"Samsung NX1",
 	"Samsung NX5",
 	"Samsung NX10",
@@ -1102,6 +1132,7 @@ static const char *static_camera_list[] = {
 	"Seitz Roundshot D2Xs",
 	"Skydio 2+",
 	"Sigma fp",
+	"Sigma fp L",
 #ifdef USE_X3FTOOLS
 	"Sigma SD9 (raw decode only)",
 	"Sigma SD10 (raw decode only)",
@@ -1165,6 +1196,7 @@ static const char *static_camera_list[] = {
 	"Sony ILCE-7SM3 (A7S III)",
 	"Sony ILCE-9 (A9)",
 	"Sony ILCE-9M2 (A9 II)",
+	"Sony ILCE-9M3 (A9 III)",
 	"Sony ILCA-68 (A68)",
 	"Sony ILCA-77M2 (A77-II)",
 	"Sony ILCA-99M2 (A99-II)",
@@ -1178,7 +1210,8 @@ static const char *static_camera_list[] = {
 	"Sony ILCE-6500",
 	"Sony ILCE-6600",
 	"Sony ILCE-6700",
-	"Sony ILCE-QX1",
+	"Sony ILCE-QX1 / UMC-R10C",
+	"Sony ILX-LR1",
 	"Sony DSC-F828",
 	"Sony DSC-HX95",
 	"Sony DSC-HX99",
@@ -1256,6 +1289,7 @@ static const char *static_camera_list[] = {
 	"Sony ZV-1M2",
 	"Sony ZV-E1",
 	"Sony ZV-E10",
+	"Sony ZV-E10 II",
 	"STV680 VGA",
 	"PtGrey GRAS-50S5C",
 	"JaiPulnix BB-500CL",
