@@ -18,17 +18,20 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
-#include "decompressors/CrwDecompressor.h" // for CrwDecompressor
-#include "MemorySanitizer.h"               // for MSan
-#include "common/RawImage.h"               // for RawImage, RawImageData
-#include "common/RawspeedException.h"      // for RawspeedException
-#include "fuzz/Common.h"                   // for CreateRawImage
-#include "io/Buffer.h"                     // for Buffer, DataBuffer
-#include "io/ByteStream.h"                 // for ByteStream
-#include "io/Endianness.h"                 // for Endianness, Endianness::little
-#include <cassert>                         // for assert
-#include <cstdint>                         // for uint32_t, uint8_t
-#include <cstdio>                          // for size_t
+#include "decompressors/CrwDecompressor.h"
+#include "MemorySanitizer.h"
+#include "adt/Array1DRef.h"
+#include "adt/Casts.h"
+#include "adt/Optional.h"
+#include "common/RawImage.h"
+#include "common/RawspeedException.h"
+#include "fuzz/Common.h"
+#include "io/Buffer.h"
+#include "io/ByteStream.h"
+#include "io/Endianness.h"
+#include <cassert>
+#include <cstdint>
+#include <cstdio>
 
 extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size);
 
@@ -36,7 +39,8 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size) {
   assert(Data);
 
   try {
-    const rawspeed::Buffer b(Data, Size);
+    const rawspeed::Buffer b(
+        Data, rawspeed::implicit_cast<rawspeed::Buffer::size_type>(Size));
     const rawspeed::DataBuffer db(b, rawspeed::Endianness::little);
     rawspeed::ByteStream bs(db);
 
@@ -45,14 +49,21 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size) {
     const uint32_t dec_table = bs.getU32();
     const uint32_t lowbits = bs.getU32();
 
-    rawspeed::CrwDecompressor c(mRaw, dec_table, lowbits,
-                                bs.getStream(bs.getRemainSize()));
+    rawspeed::Optional<rawspeed::Array1DRef<const uint8_t>> lowbitInput;
+    if (lowbits != 0) {
+      lowbitInput = bs.getBuffer(lowbits);
+    }
+
+    rawspeed::Array1DRef<const uint8_t> input =
+        bs.peekRemainingBuffer().getAsArray1DRef();
+
+    rawspeed::CrwDecompressor c(mRaw, dec_table, input, lowbitInput);
     mRaw->createData();
     c.decompress();
 
     rawspeed::MSan::CheckMemIsInitialized(
         mRaw->getByteDataAsUncroppedArray2DRef());
-  } catch (const rawspeed::RawspeedException&) {
+  } catch (const rawspeed::RawspeedException&) { // NOLINT(bugprone-empty-catch)
     // Exceptions are good, crashes are bad.
   }
 
