@@ -81,7 +81,6 @@ public:
 
   PrefixCodeLookupDecoder(PrefixCode<CodeTag>) = delete;
   PrefixCodeLookupDecoder(const PrefixCode<CodeTag>&) = delete;
-  // NOLINTNEXTLINE(cppcoreguidelines-rvalue-reference-param-not-moved)
   PrefixCodeLookupDecoder(PrefixCode<CodeTag>&&) = delete;
 
 protected:
@@ -114,26 +113,25 @@ public:
   }
 
   template <typename BIT_STREAM>
-  inline typename Traits::CodeValueTy decodeCodeValue(BIT_STREAM& bs) const {
+  typename Traits::CodeValueTy decodeCodeValue(BIT_STREAM& bs) const {
     static_assert(
         BitStreamerTraits<BIT_STREAM>::canUseWithPrefixCodeDecoder,
         "This BitStreamer specialization is not marked as usable here");
-    invariant(!Base::fullDecode);
+    invariant(!Base::isFullDecode());
     return decode<BIT_STREAM, false>(bs);
   }
 
-  template <typename BIT_STREAM>
-  inline int decodeDifference(BIT_STREAM& bs) const {
+  template <typename BIT_STREAM> int decodeDifference(BIT_STREAM& bs) const {
     static_assert(
         BitStreamerTraits<BIT_STREAM>::canUseWithPrefixCodeDecoder,
         "This BitStreamer specialization is not marked as usable here");
-    invariant(Base::fullDecode);
+    invariant(Base::isFullDecode());
     return decode<BIT_STREAM, true>(bs);
   }
 
 protected:
   template <typename BIT_STREAM>
-  inline std::pair<typename Base::CodeSymbol, int /*codeValue*/>
+  std::pair<typename Base::CodeSymbol, int /*codeValue*/>
   finishReadingPartialSymbol(BIT_STREAM& bs,
                              typename Base::CodeSymbol partial) const {
     static_assert(
@@ -166,7 +164,7 @@ protected:
   }
 
   template <typename BIT_STREAM>
-  inline std::pair<typename Base::CodeSymbol, int /*codeValue*/>
+  std::pair<typename Base::CodeSymbol, int /*codeValue*/>
   readSymbol(BIT_STREAM& bs) const {
     // Start from completely unknown symbol.
     typename Base::CodeSymbol partial;
@@ -182,8 +180,8 @@ public:
   // one to return the fully decoded diff.
   // All ifs depending on this bool will be optimized out by the compiler
   template <typename BIT_STREAM, bool FULL_DECODE>
-  inline int decode(BIT_STREAM& bs) const {
-    invariant(FULL_DECODE == Base::fullDecode);
+  int decode(BIT_STREAM& bs) const {
+    invariant(FULL_DECODE == Base::isFullDecode());
     bs.fill(32);
 
     typename Base::CodeSymbol symbol;
