@@ -75,7 +75,7 @@ void RawDecoder::decodeUncompressed(const TiffIFD* rawIFD,
 
   if (yPerSlice == 0 || yPerSlice > static_cast<uint32_t>(mRaw->dim.y) ||
       roundUpDivisionSafe(mRaw->dim.y, yPerSlice) != counts->count) {
-    ThrowRDE("Invalid y per slice %u or strip count %u (height = %u)",
+    ThrowRDE("Invalid y per slice %u or strip count %u (height = %d)",
              yPerSlice, counts->count, mRaw->dim.y);
   }
 
