@@ -21,9 +21,11 @@
 
 #include "decoders/Rw2Decoder.h"
 #include "adt/Array1DRef.h"
+#include "adt/Array1DRefExtras.h"
 #include "adt/Array2DRef.h"
 #include "adt/Point.h"
 #include "bitstreams/BitStreams.h"
+#include "common/BayerPhase.h"
 #include "common/Common.h"
 #include "common/RawImage.h"
 #include "decoders/RawDecoderException.h"
@@ -31,6 +33,7 @@
 #include "decompressors/PanasonicV5Decompressor.h"
 #include "decompressors/PanasonicV6Decompressor.h"
 #include "decompressors/PanasonicV7Decompressor.h"
+#include "decompressors/PanasonicV8Decompressor.h"
 #include "decompressors/UncompressedDecompressor.h"
 #include "io/Buffer.h"
 #include "io/ByteStream.h"
@@ -40,11 +43,15 @@
 #include "tiff/TiffEntry.h"
 #include "tiff/TiffIFD.h"
 #include "tiff/TiffTag.h"
+#include <algorithm>
 #include <array>
+#include <cassert>
 #include <cmath>
 #include <cstdint>
+#include <limits>
 #include <memory>
 #include <string>
+#include <vector>
 
 using std::fabs;
 
@@ -62,6 +69,200 @@ bool Rw2Decoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
   return make == "Panasonic" || make == "LEICA" || make == "LEICA CAMERA AG";
 }
 
+namespace {
+
+/// Retrieve list of values from Panasonic TiffTag
+template <typename T>
+void getPanasonicTiffVector(const TiffIFD& ifd, TiffTag tag,
+                            std::vector<T>& output) {
+  ByteStream bs = ifd.getEntry(tag)->getData();
+  output.resize(bs.getU16());
+
+  // Note: Relying on ByteStream and its parent classes to prevent out-of-bounds
+  // reading.
+  for (T& v : output)
+    v = bs.get<T>();
+}
+
+/// Decompressor parameters populated from tags. They remain constant after
+/// construction.
+struct DecompressorV8Params {
+  std::vector<uint32_t> stripByteOffsets;
+  std::vector<uint32_t> stripLineOffsets;
+  std::vector<uint32_t> stripBitLengths;
+  std::vector<uint16_t> stripWidths;
+  std::vector<uint16_t> stripHeights;
+  uint16_t horizontalStripCount;
+  uint16_t verticalStripCount;
+
+  PanasonicV8Decompressor::Bayer2x2 initialPrediction;
+
+  /// Decoding shift down value. Appears to be unused.
+  std::vector<uint16_t> shiftDown;
+
+  uint16_t gammaClipVal;
+
+  void validate() const;
+
+  DecompressorV8Params() = delete;
+
+  explicit DecompressorV8Params(const TiffIFD& ifd);
+};
+
+void DecompressorV8Params::validate() const {
+  const unsigned totalStrips = horizontalStripCount * verticalStripCount;
+
+  // Check that we won't be going OOB on any of these strip lists
+  if (totalStrips > stripByteOffsets.size())
+    ThrowRDE("Strip byte offset list does not have enough entries for the "
+             "number of strips!");
+  if (totalStrips > stripWidths.size())
+    ThrowRDE("Strip widths list does not have enough entries for the number of "
+             "strips!");
+  if (totalStrips > stripHeights.size())
+    ThrowRDE("Strip heights list does not have enough entries for the number "
+             "of strips!");
+  if (totalStrips > stripLineOffsets.size())
+    ThrowRDE("Strip line offset list does not have enough entries for the "
+             "number of strips!");
+  if (totalStrips > stripBitLengths.size())
+    ThrowRDE("Strip bit length list does not have enough entries for the "
+             "number of strips!");
+
+  if (std::any_of(shiftDown.begin(), shiftDown.end(),
+                  [](uint16_t x) { return x != 0; })) {
+    ThrowRDE("Non-zero shift down value encountered! Shift down decoding has "
+             "never been tested!");
+  }
+
+  if (gammaClipVal != std::numeric_limits<uint16_t>::max()) {
+    ThrowRDE("Got non-no-op gammaClipVal (%u). Not known to happen "
+             "in-the-wild. Please file a bug!",
+             gammaClipVal);
+  }
+}
+
+DecompressorV8Params::DecompressorV8Params(const TiffIFD& ifd) {
+  // NOLINTBEGIN(cppcoreguidelines-prefer-member-initializer)
+  horizontalStripCount =
+      ifd.getEntry(TiffTag::PANASONIC_V8_NUMBER_OF_STRIPS_H)->getU16();
+  verticalStripCount =
+      ifd.getEntry(TiffTag::PANASONIC_V8_NUMBER_OF_STRIPS_V)->getU16();
+
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_STRIP_BYTE_OFFSETS,
+                         stripByteOffsets);
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_STRIP_LINE_OFFSETS,
+                         stripLineOffsets);
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_STRIP_DATA_SIZE,
+                         stripBitLengths);
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_STRIP_WIDTHS, stripWidths);
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_STRIP_HEIGHTS,
+                         stripHeights);
+
+  // Get decoder's initial prediction value:
+  // Note, the positions of the green samples are swapped. This is intentional,
+  // the original implementation did this each swap redundantly during decoding
+  // of each tile.
+  initialPrediction[0] =
+      ifd.getEntry(TiffTag::PANASONIC_V8_INIT_PRED_RED)->getU16();
+  initialPrediction[2] =
+      ifd.getEntry(TiffTag::PANASONIC_V8_INIT_PRED_GREEN1)->getU16();
+  initialPrediction[1] =
+      ifd.getEntry(TiffTag::PANASONIC_V8_INIT_PRED_GREEN2)->getU16();
+  initialPrediction[3] =
+      ifd.getEntry(TiffTag::PANASONIC_V8_INIT_PRED_BLUE)->getU16();
+
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_HUF_SHIFT_DOWN, shiftDown);
+
+  gammaClipVal = ifd.getEntry(TiffTag::PANASONIC_V8_CLIP_VAL)->getU16();
+  // NOLINTEND(cppcoreguidelines-prefer-member-initializer)
+
+  validate();
+}
+
+/// Maybe the most complicated part of the entire file format, and seemingly,
+/// completely unused.
+void populateGammaLUT(const DecompressorV8Params& mParams, const TiffIFD& ifd) {
+  std::vector<uint16_t> mGammaLUT;
+
+  // Retrieve encoded gamma curve from tags.
+  std::vector<uint32_t> encodedGammaPoints;
+  std::vector<uint32_t> encodedGammaSlopes;
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_GAMMA_POINTS,
+                         encodedGammaPoints);
+  getPanasonicTiffVector(ifd, TiffTag::PANASONIC_V8_GAMMA_SLOPES,
+                         encodedGammaSlopes);
+
+  // Determine if the points and slopes are all set to zero and 65536
+  // respectively. If so, no gamma function needs to be applied. This is
+  // currently true of all tested RW2 files.
+  const bool gamamPointsAreIdentity =
+      std::all_of(encodedGammaPoints.cbegin(), encodedGammaPoints.cend(),
+                  [](const uint32_t p) { return p == 0U; });
+  const bool gammaSlopesAreIdentity =
+      std::all_of(encodedGammaSlopes.cbegin(), encodedGammaSlopes.cend(),
+                  [](const uint32_t s) { return s == 65536U; });
+
+  if (!gamamPointsAreIdentity || !gammaSlopesAreIdentity) {
+    // Generate gamma LUT based on retrieved curve.
+    ThrowRDE("Non-identity gamma curve encountered. Never encountered in any "
+             "testing samples!");
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunreachable-code"
+    if (encodedGammaPoints.size() != 6 || encodedGammaSlopes.size() != 6) {
+      ThrowRDE("Gamma curve point and/or slope list is not the expected length "
+               "of 6");
+    }
+#pragma GCC diagnostic pop
+  }
+}
+
+std::vector<Array1DRef<const uint8_t>>
+getInputStrips(const DecompressorV8Params& mParams, Buffer mInputFile) {
+  std::vector<Array1DRef<const uint8_t>> mStrips;
+
+  const int totalStrips =
+      mParams.horizontalStripCount * mParams.verticalStripCount;
+
+  for (int stripIdx = 0; stripIdx < totalStrips; ++stripIdx) {
+    const uint32_t stripSize = (mParams.stripBitLengths[stripIdx] + 7) / 8;
+    const uint32_t stripOffset = mParams.stripByteOffsets[stripIdx];
+
+    // Note: Relying on Buffer to catch OOB access attempts
+    DataBuffer stripBuffer(mInputFile.getSubView(stripOffset, stripSize),
+                           Endianness::big);
+    mStrips.emplace_back(stripBuffer.getAsArray1DRef());
+  }
+
+  return mStrips;
+}
+
+} // namespace
+
+RawImage Rw2Decoder::decodeRawV8(const TiffIFD& raw) const {
+  parseCFA();
+  if (getAsBayerPhase(mRaw->cfa) != BayerPhase::RGGB)
+    ThrowRDE("Unexpected CFA, only RGGB is supported");
+
+  const DecompressorV8Params mParams(raw);
+  populateGammaLUT(mParams, raw);
+  const std::vector<Array1DRef<const uint8_t>> mStrips =
+      getInputStrips(mParams, mFile);
+
+  PanasonicV8Decompressor::DecompressorParamsBuilder b(
+      mRaw->dim, mParams.initialPrediction, getAsArray1DRef(mStrips),
+      getAsArray1DRef(mParams.stripLineOffsets),
+      getAsArray1DRef(mParams.stripWidths),
+      getAsArray1DRef(mParams.stripHeights),
+      raw.getEntry(TiffTag::PANASONIC_V8_HUF_TABLE)->getData());
+
+  PanasonicV8Decompressor v8(mRaw, b.getDecompressorParams());
+  mRaw->createData();
+  v8.decompress();
+  return mRaw;
+}
+
 RawImage Rw2Decoder::decodeRawInternal() {
 
   const TiffIFD* raw = nullptr;
@@ -170,6 +371,14 @@ RawImage Rw2Decoder::decodeRawInternal() {
       v7.decompress();
       return mRaw;
     }
+    case 8: {
+      // Known values are 12, 14, and 16. Other less than 16 should decompress
+      // fine.
+      if (bitsPerSample > 16)
+        ThrowRDE("Version %i: unexpected bits per sample: %i", version,
+                 bitsPerSample);
+      return decodeRawV8(*raw);
+    }
     default:
       ThrowRDE("Version %i is unsupported", version);
     }
@@ -273,7 +482,7 @@ void Rw2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
     auto blackLevelSeparate1D = *mRaw->blackLevelSeparate->getAsArray1DRef();
     for (int i = 0; i < 2; i++) {
       for (int j = 0; j < 2; j++) {
-        const int k = i + 2 * j;
+        const int k = i + (2 * j);
         const CFAColor c = mRaw->cfa.getColorAt(i, j);
         switch (c) {
         case CFAColor::RED:
@@ -297,19 +506,23 @@ void Rw2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
   if (raw->hasEntry(static_cast<TiffTag>(0x0024)) &&
       raw->hasEntry(static_cast<TiffTag>(0x0025)) &&
       raw->hasEntry(static_cast<TiffTag>(0x0026))) {
-    mRaw->metadata.wbCoeffs[0] = static_cast<float>(
+    std::array<float, 4> wbCoeffs = {};
+    wbCoeffs[0] = static_cast<float>(
         raw->getEntry(static_cast<TiffTag>(0x0024))->getU16());
-    mRaw->metadata.wbCoeffs[1] = static_cast<float>(
+    wbCoeffs[1] = static_cast<float>(
         raw->getEntry(static_cast<TiffTag>(0x0025))->getU16());
-    mRaw->metadata.wbCoeffs[2] = static_cast<float>(
+    wbCoeffs[2] = static_cast<float>(
         raw->getEntry(static_cast<TiffTag>(0x0026))->getU16());
+    mRaw->metadata.wbCoeffs = wbCoeffs;
   } else if (raw->hasEntry(static_cast<TiffTag>(0x0011)) &&
              raw->hasEntry(static_cast<TiffTag>(0x0012))) {
-    mRaw->metadata.wbCoeffs[0] = static_cast<float>(
+    std::array<float, 4> wbCoeffs = {};
+    wbCoeffs[0] = static_cast<float>(
         raw->getEntry(static_cast<TiffTag>(0x0011))->getU16());
-    mRaw->metadata.wbCoeffs[1] = 256.0F;
-    mRaw->metadata.wbCoeffs[2] = static_cast<float>(
+    wbCoeffs[1] = 256.0F;
+    wbCoeffs[2] = static_cast<float>(
         raw->getEntry(static_cast<TiffTag>(0x0012))->getU16());
+    mRaw->metadata.wbCoeffs = wbCoeffs;
   }
 }
 
@@ -321,16 +534,16 @@ std::string Rw2Decoder::guessMode() const {
 
   ratio = static_cast<float>(mRaw->dim.x) / static_cast<float>(mRaw->dim.y);
 
-  float min_diff = fabs(ratio - 16.0F / 9.0F);
+  float min_diff = fabs(ratio - (16.0F / 9.0F));
   std::string closest_match = "16:9";
 
-  float t = fabs(ratio - 3.0F / 2.0F);
+  float t = fabs(ratio - (3.0F / 2.0F));
   if (t < min_diff) {
     closest_match = "3:2";
     min_diff = t;
   }
 
-  t = fabs(ratio - 4.0F / 3.0F);
+  t = fabs(ratio - (4.0F / 3.0F));
   if (t < min_diff) {
     closest_match = "4:3";
     min_diff = t;
