@@ -21,16 +21,21 @@
 */
 
 #include "decoders/SimpleTiffDecoder.h"
-#include "adt/Point.h"                    // for iPoint2D
-#include "common/RawImage.h"              // for RawImage, RawImageData
-#include "decoders/RawDecoderException.h" // for ThrowException, ThrowRDE
-#include "io/Buffer.h"                    // for Buffer
-#include "tiff/TiffEntry.h"               // for TiffEntry
-#include "tiff/TiffIFD.h"                 // for TiffIFD
-#include "tiff/TiffTag.h"                 // for TiffTag, TiffTag::IMAGELENGTH
+#include "adt/Point.h"
+#include "common/RawImage.h"
+#include "decoders/RawDecoderException.h"
+#include "io/Buffer.h"
+#include "tiff/TiffEntry.h"
+#include "tiff/TiffIFD.h"
+#include "tiff/TiffTag.h"
 
 namespace rawspeed {
 
+void SimpleTiffDecoder::anchor() const {
+  // Empty out-of-line definition for the purpose of anchoring
+  // the class's vtable to this Translational Unit.
+}
+
 void SimpleTiffDecoder::prepareForRawDecoding() {
   raw = getIFDWithLargestImage();
   width = raw->getEntry(TiffTag::IMAGEWIDTH)->getU32();
