@@ -22,17 +22,19 @@
 
 #pragma once
 
-#include "decoders/AbstractTiffDecoder.h" // for AbstractTiffDecoder
-#include "io/Buffer.h"                    // for Buffer
-#include "tiff/TiffIFD.h"                 // for TiffIFD (ptr only), TiffRo...
-#include <cstdint>                        // for uint32_t
-#include <utility>                        // for move
+#include "decoders/AbstractTiffDecoder.h"
+#include "io/Buffer.h"
+#include "tiff/TiffIFD.h"
+#include <cstdint>
+#include <utility>
 
 namespace rawspeed {
 
 class Buffer;
 
 class SimpleTiffDecoder : public AbstractTiffDecoder {
+  void anchor() const final;
+
   virtual void checkImageDimensions() = 0;
 
 public:
