@@ -48,7 +48,7 @@ HasselbladDecompressor::HasselbladDecompressor(RawImage mRaw_,
   // FIXME: could be wrong. max "active pixels" - "100 MP"
   if (!mRaw->dim.hasPositiveArea() || mRaw->dim.x % 2 != 0 ||
       mRaw->dim.x > 12000 || mRaw->dim.y > 8842) {
-    ThrowRDE("Unexpected image dimensions found: (%u; %u)", mRaw->dim.x,
+    ThrowRDE("Unexpected image dimensions found: (%d; %d)", mRaw->dim.x,
              mRaw->dim.y);
   }
 
