@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2009-2024 darktable developers.
+    Copyright (C) 2009-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,12 +26,10 @@
 
 G_BEGIN_DECLS
 
-#define DT_GUI_IOP_MODULE_CONTROL_SPACING 0
-
 #define DT_GUI_THUMBSIZE_REDUCE 0.7f
 
-/* helper macro that applies the DPI transformation to fixed pixel values. input should be defaulting to 96
- * DPI */
+/* helper macro that applies the DPI transformation to fixed pixel
+ * values. input should be defaulting to 96 DPI */
 #define DT_PIXEL_APPLY_DPI(value) ((value) * darktable.gui->dpi_factor)
 
 #define DT_RESIZE_HANDLE_SIZE DT_PIXEL_APPLY_DPI(5)
@@ -102,6 +100,14 @@ typedef enum dt_gui_color_t
   DT_GUI_COLOR_LAST
 } dt_gui_color_t;
 
+typedef enum dt_gui_session_type_t
+{
+  DT_GUI_SESSION_UNKNOWN,
+  DT_GUI_SESSION_X11,
+  DT_GUI_SESSION_QUARTZ,
+  DT_GUI_SESSION_WAYLAND,
+} dt_gui_session_type_t;
+
 typedef struct dt_gui_gtk_t
 {
   struct dt_ui_t *ui;
@@ -325,63 +331,63 @@ typedef enum dt_ui_border_t
 void dt_ui_container_swap_left_right(struct dt_ui_t *ui,
                                      gboolean swap);
 /** \brief add's a widget to a defined container */
-void dt_ui_container_add_widget(struct dt_ui_t *ui,
+void dt_ui_container_add_widget(const struct dt_ui_t *ui,
                                 const dt_ui_container_t c,
                                 GtkWidget *w);
 /** \brief gives a widget focus in the container */
-void dt_ui_container_focus_widget(struct dt_ui_t *ui,
+void dt_ui_container_focus_widget(const struct dt_ui_t *ui,
                                   const dt_ui_container_t c,
                                   GtkWidget *w);
 /** \brief calls a callback on all children widgets from container */
-void dt_ui_container_foreach(struct dt_ui_t *ui,
+void dt_ui_container_foreach(const struct dt_ui_t *ui,
                              const dt_ui_container_t c,
                              GtkCallback callback);
 /** \brief destroy all child widgets from container */
-void dt_ui_container_destroy_children(struct dt_ui_t *ui,
+void dt_ui_container_destroy_children(const struct dt_ui_t *ui,
                                       const dt_ui_container_t c);
 /** \brief shows/hide a panel */
-void dt_ui_panel_show(struct dt_ui_t *ui,
+void dt_ui_panel_show(const struct dt_ui_t *ui,
                       const dt_ui_panel_t,
                       const gboolean show,
                       const gboolean write);
 /** \brief restore saved state of panel visibility for current view */
-void dt_ui_restore_panels(struct dt_ui_t *ui);
+void dt_ui_restore_panels(const struct dt_ui_t *ui);
 /** \brief update scrollbars for current view */
 void dt_ui_update_scrollbars(struct dt_ui_t *ui);
 /** show or hide scrollbars */
 void dt_ui_scrollbars_show(struct dt_ui_t *ui, const gboolean show);
 /** \brief toggle view of panels eg. collapse/expands to previous view state */
-void dt_ui_toggle_panels_visibility(struct dt_ui_t *ui);
+void dt_ui_toggle_panels_visibility(const struct dt_ui_t *ui);
 /** \brief draw user's attention */
 void dt_ui_notify_user();
 /** \brief get visible state of panel */
-gboolean dt_ui_panel_visible(struct dt_ui_t *ui,
+gboolean dt_ui_panel_visible(const struct dt_ui_t *ui,
                              const dt_ui_panel_t);
 /**  \brief get width of right, left, or bottom panel */
 int dt_ui_panel_get_size(struct dt_ui_t *ui,
                          const dt_ui_panel_t p);
 /**  \brief set width of right, left, or bottom panel */
-void dt_ui_panel_set_size(struct dt_ui_t *ui,
+void dt_ui_panel_set_size(const struct dt_ui_t *ui,
                           const dt_ui_panel_t p,
                           int s);
 /** \brief is the panel ancestor of widget */
-gboolean dt_ui_panel_ancestor(struct dt_ui_t *ui,
+gboolean dt_ui_panel_ancestor(const struct dt_ui_t *ui,
                               const dt_ui_panel_t p,
                               GtkWidget *w);
 /** \brief get the center drawable widget */
-GtkWidget *dt_ui_center(struct dt_ui_t *ui);
-GtkWidget *dt_ui_center_base(struct dt_ui_t *ui);
-GtkWidget *dt_ui_snapshot(struct dt_ui_t *ui);
+GtkWidget *dt_ui_center(const struct dt_ui_t *ui);
+GtkWidget *dt_ui_center_base(const struct dt_ui_t *ui);
+GtkWidget *dt_ui_snapshot(const struct dt_ui_t *ui);
 /** \brief get the main window widget */
-GtkWidget *dt_ui_main_window(struct dt_ui_t *ui);
+GtkWidget *dt_ui_main_window(const struct dt_ui_t *ui);
 /** \brief get the thumb table */
-struct dt_thumbtable_t *dt_ui_thumbtable(struct dt_ui_t *ui);
+struct dt_thumbtable_t *dt_ui_thumbtable(const struct dt_ui_t *ui);
 /** \brief get the log message widget */
-GtkWidget *dt_ui_log_msg(struct dt_ui_t *ui);
+GtkWidget *dt_ui_log_msg(const struct dt_ui_t *ui);
 /** \brief get the toast message widget */
-GtkWidget *dt_ui_toast_msg(struct dt_ui_t *ui);
+GtkWidget *dt_ui_toast_msg(const struct dt_ui_t *ui);
 
-GtkBox *dt_ui_get_container(struct dt_ui_t *ui,
+GtkBox *dt_ui_get_container(const struct dt_ui_t *ui,
                             const dt_ui_container_t c);
 
 /*  activate ellipsization of the combox entries */
@@ -446,6 +452,7 @@ char *dt_gui_show_standalone_string_dialog(const char *title,
 
 // returns TRUE if YES was answered, FALSE otherwise
 gboolean dt_gui_show_yes_no_dialog(const char *title,
+                                   const char *wname,
                                    const char *format, ...);
 
 void dt_gui_add_help_link(GtkWidget *widget,
@@ -464,7 +471,7 @@ void dt_configure_ppd_dpi(dt_gui_gtk_t *gui);
 
 // translate key press events to remove any modifiers used to produce the keyval
 // for example when the shift key is used to create the asterisk character
-guint dt_gui_translated_key_state(GdkEventKey *event);
+guint dt_gui_translated_key_state(const GdkEventKey *event);
 
 // return modifier keys currently pressed, independent of any key event
 GdkModifierType dt_key_modifier_state();
@@ -526,15 +533,46 @@ void dt_gui_new_collapsible_section(dt_gui_collapsible_section_t *cs,
 void dt_gui_collapsible_section_set_label(dt_gui_collapsible_section_t *cs,
                                           const char *label);
 // routine to be called from gui_update
-void dt_gui_update_collapsible_section(dt_gui_collapsible_section_t *cs);
+void dt_gui_update_collapsible_section(const dt_gui_collapsible_section_t *cs);
 
 // routine to hide the collapsible section
-void dt_gui_hide_collapsible_section(dt_gui_collapsible_section_t *cs);
+void dt_gui_hide_collapsible_section(const dt_gui_collapsible_section_t *cs);
 
 // is delay between first and second click/press longer than double-click time?
 gboolean dt_gui_long_click(const guint second,
                            const guint first);
 
+#define ASSERT_FUNC_TYPE(func, expected_type) (void)(1 ? (func) : (expected_type)0)
+
+GtkGestureSingle *(dt_gui_connect_click)(GtkWidget *widget,
+                                         GCallback pressed,
+                                         GCallback released,
+                                         gpointer data);
+#define dt_gui_connect_click(widget, pressed, released, data) ( \
+  ASSERT_FUNC_TYPE(pressed, void(*)(GtkGestureSingle *, int, double, double, __typeof__(data))), \
+  ASSERT_FUNC_TYPE(released, void(*)(GtkGestureSingle *, int, double, double, __typeof__(data))), \
+  dt_gui_connect_click(GTK_WIDGET(widget), G_CALLBACK(pressed), G_CALLBACK(released), (data)))
+#define dt_gui_connect_click_all(widget, pressed, released, data) \
+  gtk_gesture_single_set_button(dt_gui_connect_click(widget, pressed, released, data), 0)
+
+#define dt_gui_claim(gesture) \
+      gtk_gesture_set_state(GTK_GESTURE(gesture), GTK_EVENT_SEQUENCE_CLAIMED)
+
+GtkEventController *(dt_gui_connect_motion)(GtkWidget *widget,
+                                            GCallback motion,
+                                            GCallback enter,
+                                            GCallback leave,
+                                            gpointer data);
+#define dt_gui_connect_motion(widget, motion, enter, leave, data) ( \
+  ASSERT_FUNC_TYPE(motion, void(*)(GtkEventControllerMotion *, double, double, __typeof__(data))), \
+  ASSERT_FUNC_TYPE(enter, void(*)(GtkEventControllerMotion *, double, double, __typeof__(data))), \
+  ASSERT_FUNC_TYPE(leave, void(*)(GtkEventControllerMotion *, __typeof__(data))), \
+  dt_gui_connect_motion(GTK_WIDGET(widget), G_CALLBACK(motion), G_CALLBACK(enter), G_CALLBACK(leave), (data)))
+
+// GTK4 gtk_event_controller_get_current_event_state(GTK_EVENT_CONTROLLER(controller));
+#define dt_modifier_eq(controller, mask)\
+  dt_modifier_is(dt_key_modifier_state(), mask)
+
 // control whether the mouse pointer displays as a "busy" cursor, e.g. watch or timer
 // the calls may be nested, but must be matched
 void dt_gui_cursor_set_busy();
@@ -545,10 +583,24 @@ void dt_gui_cursor_clear_busy();
 // (i.e. the current function will do a lot of work before returning)
 void dt_gui_process_events();
 
+#ifdef __cplusplus
+extern "C++"
+{
+template<typename... Widgets>
+inline GtkWidget *dt_gui_box_add(gpointer box, Widgets*... w)
+{
+  // fold expression: expands to gtk_container_add(box, a), gtk_container_add(box, b), ...
+  (gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(w)), ...);
+  return GTK_WIDGET(box);
+}
+}
+#else
 GtkWidget *(dt_gui_box_add)(const char *file, const int line, const char *function, GtkBox *box, gpointer list[]);
-#define dt_gui_box_add(box, ...) dt_gui_box_add(__FILE__, __LINE__, __FUNCTION__, GTK_BOX(box), (gpointer[]){ __VA_ARGS__, (gpointer)-1 })
-#define dt_gui_hbox(...) dt_gui_box_add(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0), __VA_ARGS__)
-#define dt_gui_vbox(...) dt_gui_box_add(gtk_box_new(GTK_ORIENTATION_VERTICAL, 0), __VA_ARGS__)
+#define dt_gui_box_add(box, ...) dt_gui_box_add(__FILE__, __LINE__, __FUNCTION__, GTK_BOX(box), (gpointer[]){ __VA_ARGS__ __VA_OPT__(,) (gpointer)-1 })
+#endif
+#define dt_gui_hbox(...) dt_gui_box_add(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0) __VA_OPT__(,) __VA_ARGS__)
+#define dt_gui_vbox(...) dt_gui_box_add(gtk_box_new(GTK_ORIENTATION_VERTICAL, 0) __VA_OPT__(,) __VA_ARGS__)
+#define dt_gui_dialog_add(dialog, ...) dt_gui_box_add(gtk_dialog_get_content_area(GTK_DIALOG(dialog)), __VA_ARGS__)
 #define dt_gui_expand(widget) dt_gui_expand(GTK_WIDGET(widget))
 #define dt_gui_align_right(widget) dt_gui_align_right(GTK_WIDGET(widget))
 
@@ -564,6 +616,14 @@ static inline GtkWidget *(dt_gui_align_right)(GtkWidget *widget)
   return dt_gui_expand(widget);
 }
 
+static inline GtkWidget *dt_gui_scroll_wrap(GtkWidget *widget)
+{
+  GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  gtk_widget_set_vexpand(scrolled_window, TRUE);
+  gtk_container_add(GTK_CONTAINER(scrolled_window), widget);
+  return scrolled_window;
+}
+
 // Simulate a mouse button event (button is 1, 2, 3 - mouse button) sent to a Widget
 void dt_gui_simulate_button_event(GtkWidget *widget,
                                   const GdkEventType eventtype,
@@ -572,6 +632,12 @@ void dt_gui_simulate_button_event(GtkWidget *widget,
 // Setup auto-commit on focus loss for editable renderers
 void dt_gui_commit_on_focus_loss(GtkCellRenderer *renderer, GtkCellEditable **active_editable);
 
+// restore dialog size from config file
+void dt_gui_dialog_restore_size(GtkDialog *dialog, const char *conf);
+
+// returns the session type at runtime
+dt_gui_session_type_t dt_gui_get_session_type(void);
+
 G_END_DECLS
 
 // clang-format off
