@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2009-2024 darktable developers.
+    Copyright (C) 2009-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -91,6 +91,8 @@ gboolean dt_imageio_export(const dt_imgid_t imgid,
                       struct dt_imageio_module_data_t *format_params,
                       const gboolean high_quality,
                       const gboolean upscale,
+                      const gboolean is_scaling,
+                      const double scale_factor,
                       const gboolean copy_metadata,
                       const gboolean export_masks,
                       dt_colorspaces_color_profile_type_t icc_type,
@@ -110,6 +112,7 @@ gboolean dt_imageio_export_with_flags(const dt_imgid_t imgid, const char *filena
                                  const gboolean high_quality,
                                  const gboolean upscale,
                                  const gboolean is_scaling,
+                                 const double scale_factor,
                                  const gboolean thumbnail_export,
                                  const char *filter,
                                  const gboolean copy_metadata,
@@ -124,14 +127,6 @@ gboolean dt_imageio_export_with_flags(const dt_imgid_t imgid, const char *filena
                                  dt_export_metadata_t *metadata,
                                  const int history_end);
 
-size_t dt_imageio_write_pos(const int i,
-                            const int j,
-                            const int wd,
-                            const int ht,
-                            const float fwd,
-                            const float fht,
-                            const dt_image_orientation_t orientation);
-
 // general, efficient buffer flipping function using memcopies
 void dt_imageio_flip_buffers(char *out,
                              const char *in,
