@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2010-2023 darktable developers.
+    Copyright (C) 2010-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -141,6 +141,8 @@ int store(dt_imageio_module_storage_t *self,
           const int total,
           const gboolean high_quality,
           const gboolean upscale,
+          const gboolean is_scaling,
+          const double scale_factor,
           const gboolean export_masks,
           dt_colorspaces_color_profile_type_t icc_type,
           const gchar *icc_filename,
@@ -176,7 +178,8 @@ int store(dt_imageio_module_storage_t *self,
   attachment->file = g_build_filename(tmpdir, dirname, (char *)NULL);
 
   if(dt_imageio_export(imgid, attachment->file, format, fdata, high_quality,
-                       upscale, TRUE, export_masks, icc_type,
+                       upscale, is_scaling, scale_factor,
+                       TRUE, export_masks, icc_type,
                        icc_filename, icc_intent, self, sdata, num, total, metadata) != 0)
   {
     dt_print(DT_DEBUG_ALWAYS,
