@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2011-2024 darktable developers.
+    Copyright (C) 2011-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -190,10 +190,6 @@ void gui_init(dt_imageio_module_storage_t *self)
 {
   gallery_t *d = malloc(sizeof(gallery_t));
   self->gui_data = (void *)d;
-  self->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-  GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_pack_start(GTK_BOX(self->widget), hbox, TRUE, TRUE, 0);
-  GtkWidget *widget;
 
   d->entry =
     GTK_ENTRY
@@ -204,25 +200,23 @@ void gui_init(dt_imageio_module_storage_t *self)
         " string manipulation\n"
         "type '$(' to activate the completion and see the list of variables"),
       dt_conf_get_string_const("plugins/imageio/storage/gallery/file_directory")));
-  dt_gtkentry_setup_completion(d->entry, dt_gtkentry_get_default_path_compl_list());
-  gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(d->entry), TRUE, TRUE, 0);
+  dt_gtkentry_setup_variables_completion(d->entry);
 
-  widget = dtgtk_button_new(dtgtk_cairo_paint_directory, CPF_NONE, NULL);
+  GtkWidget *widget = dtgtk_button_new(dtgtk_cairo_paint_directory, CPF_NONE, NULL);
   gtk_widget_set_name(widget, "non-flat");
   gtk_widget_set_tooltip_text(widget, _("select directory"));
-  gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(widget), "clicked", G_CALLBACK(button_clicked), self);
 
-  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_pack_start(GTK_BOX(self->widget), hbox, TRUE, TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(hbox), dt_ui_label_new(_("title")), FALSE, FALSE, 0);
   d->title_entry =
     GTK_ENTRY(dt_action_entry_new
               (DT_ACTION(self), N_("title"),
                G_CALLBACK(title_changed_callback), self,
                _("enter the title of the website"),
                dt_conf_get_string_const("plugins/imageio/storage/gallery/title")));
-  gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(d->title_entry), TRUE, TRUE, 0);
+
+  self->widget = dt_gui_vbox
+    (dt_gui_hbox(d->entry, widget),
+     dt_gui_hbox(dt_ui_label_new(_("title")), d->title_entry));
 }
 
 void gui_cleanup(dt_imageio_module_storage_t *self)
@@ -261,6 +255,8 @@ int store(dt_imageio_module_storage_t *self,
           const int total,
           const gboolean high_quality,
           const gboolean upscale,
+          const gboolean is_scaling,
+          const double scale_factor,
           const gboolean export_masks,
           dt_colorspaces_color_profile_type_t icc_type,
           const gchar *icc_filename,
@@ -343,6 +339,7 @@ int store(dt_imageio_module_storage_t *self,
 
   if((metadata->flags & DT_META_METADATA) && !(metadata->flags & DT_META_CALCULATED))
   {
+    dt_pthread_mutex_lock(&darktable.metadata_threadsafe);
     res_title = dt_metadata_get(imgid, "Xmp.dc.title", NULL);
     if(res_title)
     {
@@ -354,6 +351,7 @@ int store(dt_imageio_module_storage_t *self,
     {
       description = res_desc->data;
     }
+    dt_pthread_mutex_unlock(&darktable.metadata_threadsafe);
   }
 
   char relfilename[PATH_MAX] = { 0 }, relthumbfilename[PATH_MAX] = { 0 };
@@ -399,7 +397,8 @@ int store(dt_imageio_module_storage_t *self,
   // export image to file. need this to be able to access meaningful
   // fdata->width and height below.
   if(dt_imageio_export(imgid, filename, format, fdata, high_quality,
-                       upscale, TRUE, export_masks, icc_type,
+                       upscale, is_scaling, scale_factor,
+                       TRUE, export_masks, icc_type,
                        icc_filename, icc_intent, self, sdata, num, total, metadata) != 0)
   {
     dt_print(DT_DEBUG_ALWAYS,
@@ -440,6 +439,7 @@ int store(dt_imageio_module_storage_t *self,
   ext = format->extension(fdata);
   sprintf(c, "-thumb.%s", ext);
   if(dt_imageio_export(imgid, filename, format, fdata, FALSE, TRUE, FALSE,
+                       is_scaling, scale_factor,
                        export_masks, icc_type, icc_filename,
                        icc_intent, self, sdata, num, total, NULL) != 0)
   {
