@@ -713,12 +713,12 @@ void init_presets(dt_iop_module_so_t *self)
                                                          TRUE,
                                                          DT_IOP_BORDERS_BASIS_AUTO };
   dt_gui_presets_add_generic(_("15:10 postcard white"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.color[0] = p.color[1] = p.color[2] = 0.0f;
   p.frame_color[0] = p.frame_color[1] = p.frame_color[2] = 1.0f;
   dt_gui_presets_add_generic(_("15:10 postcard black"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 }
 
 void color_picker_apply(dt_iop_module_t *self, GtkWidget *picker,
@@ -1009,40 +1009,32 @@ void gui_init(dt_iop_module_t *self)
                                   .blue = dp->frame_color[2],
                                   .alpha = 1.0 };
 
-  GtkWidget *label, *box;
-
-  box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-  label = dtgtk_reset_label_new(_("border color"), self, &p->color, 3 * sizeof(float));
-  gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0);
+  GtkWidget *label = dtgtk_reset_label_new(_("border color"), self, &p->color, 3 * sizeof(float));
   g->colorpick = gtk_color_button_new_with_rgba(&color);
   gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(g->colorpick), FALSE);
   gtk_color_button_set_title(GTK_COLOR_BUTTON(g->colorpick), _("select border color"));
   g_signal_connect(G_OBJECT(g->colorpick), "color-set",
                    G_CALLBACK(_colorpick_color_set), self);
-  gtk_box_pack_start(GTK_BOX(box), GTK_WIDGET(g->colorpick), FALSE, TRUE, 0);
-  g->border_picker = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, box);
+  g->border_picker = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, NULL);
   gtk_widget_set_tooltip_text(GTK_WIDGET(g->border_picker),
                               _("pick border color from image"));
   dt_action_define_iop(self, N_("pickers"), N_("border color"),
                        g->border_picker, &dt_action_def_toggle);
-  dt_gui_box_add(self->widget, box);
+  dt_gui_box_add(self->widget, dt_gui_hbox(dt_gui_expand(label), g->colorpick, g->border_picker));
 
-  box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
   label = dtgtk_reset_label_new(_("frame line color"), self, &p->frame_color, 3 * sizeof(float));
-  gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0);
   g->frame_colorpick = gtk_color_button_new_with_rgba(&frame_color);
   gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(g->frame_colorpick), FALSE);
   gtk_color_button_set_title(GTK_COLOR_BUTTON(g->frame_colorpick),
                              _("select frame line color"));
   g_signal_connect(G_OBJECT(g->frame_colorpick), "color-set",
                    G_CALLBACK(_frame_colorpick_color_set), self);
-  gtk_box_pack_start(GTK_BOX(box), GTK_WIDGET(g->frame_colorpick), FALSE, TRUE, 0);
-  g->frame_picker = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, box);
+  g->frame_picker = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, NULL);
   gtk_widget_set_tooltip_text(GTK_WIDGET(g->frame_picker),
                               _("pick frame line color from image"));
   dt_action_define_iop(self, N_("pickers"), N_("frame line color"),
                        g->frame_picker, &dt_action_def_toggle);
-  dt_gui_box_add(self->widget, box);
+  dt_gui_box_add(self->widget, dt_gui_hbox(dt_gui_expand(label), g->frame_colorpick, g->frame_picker));
 }
 
 // clang-format off
