@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2011-2024 darktable developers.
+    Copyright (C) 2011-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -347,14 +347,6 @@ void modify_roi_in(dt_iop_module_t *self,
   // to convert valid points to widths, we need to add one
   roi_in->width = aabb_in[2] - aabb_in[0] + 1;
   roi_in->height = aabb_in[3] - aabb_in[1] + 1;
-
-  // sanity check.
-  const float w = piece->buf_in.width * roi_out->scale;
-  const float h = piece->buf_in.height * roi_out->scale;
-  roi_in->x = CLAMP(roi_in->x, 0, (int)floorf(w));
-  roi_in->y = CLAMP(roi_in->y, 0, (int)floorf(h));
-  roi_in->width = CLAMP(roi_in->width, 1, (int)ceilf(w) - roi_in->x);
-  roi_in->height = CLAMP(roi_in->height, 1, (int)ceilf(h) - roi_in->y);
 }
 
 // 3rd (final) pass: you get this input region (may be different from
@@ -391,10 +383,11 @@ int process_cl(dt_iop_module_t *self,
   const int devid = piece->pipe->devid;
   const int width = roi_in->width;
   const int height = roi_in->height;
-  const int orientation = data->orientation;
 
   return dt_opencl_enqueue_kernel_2d_args(devid, gd->kernel_flip, width, height,
-    CLARG(dev_in), CLARG(dev_out), CLARG(width), CLARG(height), CLARG(orientation));
+    CLARG(dev_in), CLARG(dev_out),
+    CLARG(width), CLARG(height), CLARG(roi_out->width), CLARG(roi_out->height),
+    CLARG(data->orientation));
 }
 #endif
 
@@ -453,32 +446,32 @@ void init_presets(dt_iop_module_so_t *self)
 
   p.orientation = ORIENTATION_NULL;
   dt_gui_presets_add_generic(_("auto"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
   dt_gui_presets_update_autoapply(BUILTIN_PRESET("auto"), self->op, self->version(), TRUE);
 
   p.orientation = ORIENTATION_NONE;
   dt_gui_presets_add_generic(_("no rotation"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.orientation = ORIENTATION_FLIP_HORIZONTALLY;
   dt_gui_presets_add_generic(_("flip horizontally"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.orientation = ORIENTATION_FLIP_VERTICALLY;
   dt_gui_presets_add_generic(_("flip vertically"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.orientation = ORIENTATION_ROTATE_CW_90_DEG;
   dt_gui_presets_add_generic(_("rotate by -90 degrees"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.orientation = ORIENTATION_ROTATE_CCW_90_DEG;
   dt_gui_presets_add_generic(_("rotate by  90 degrees"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   p.orientation = ORIENTATION_ROTATE_180_DEG;
   dt_gui_presets_add_generic(_("rotate by 180 degrees"), self->op,
-                             self->version(), &p, sizeof(p), 1, DEVELOP_BLEND_CS_NONE);
+                             self->version(), &p, sizeof(p), TRUE, DEVELOP_BLEND_CS_NONE);
 
   dt_database_release_transaction(darktable.db);
 }
@@ -605,11 +598,9 @@ void gui_init(dt_iop_module_t *self)
   self->gui_data = NULL;
   dt_iop_flip_params_t *p = self->params;
 
-  self->widget = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-
   GtkWidget *label = dtgtk_reset_label_new(_("transform"),
                                            self, &p->orientation, sizeof(int32_t));
-  gtk_box_pack_start(GTK_BOX(self->widget), label, TRUE, TRUE, 0);
+  self->widget = dt_gui_hbox(label);
 
   dt_iop_button_new(self, N_("rotate 90 degrees CCW"),
                     G_CALLBACK(rotate_ccw), FALSE, GDK_KEY_bracketleft, 0,
