@@ -70,7 +70,7 @@ const char *name()
 int flags()
 {
   return IOP_FLAGS_ALLOW_TILING | IOP_FLAGS_TILING_FULL_ROI | IOP_FLAGS_ONE_INSTANCE
-    | IOP_FLAGS_UNSAFE_COPY;
+    | IOP_FLAGS_UNSAFE_COPY | IOP_FLAGS_HIDDEN;
 }
 
 int default_group()
@@ -105,9 +105,9 @@ static void transform(const dt_dev_pixelpipe_iop_t *const piece,
                       const float *const x,
                       float *o)
 {
-  dt_iop_rotatepixels_data_t *d = piece->data;
+  const dt_iop_rotatepixels_data_t *d = piece->data;
 
-  float pi[2] = { x[0] - d->rx * scale, x[1] - d->ry * scale };
+  const float pi[2] = { x[0] - d->rx * scale, x[1] - d->ry * scale };
 
   mul_mat_vec_2(d->m, pi, o);
 }
@@ -119,9 +119,9 @@ static void backtransform(const dt_dev_pixelpipe_iop_t *const piece,
                           const float *const x,
                           float *o)
 {
-  dt_iop_rotatepixels_data_t *d = piece->data;
+  const dt_iop_rotatepixels_data_t *d = piece->data;
 
-  float rt[] = { d->m[0], -d->m[1], -d->m[2], d->m[3] };
+  const float rt[] = { d->m[0], -d->m[1], -d->m[2], d->m[3] };
   mul_mat_vec_2(rt, x, o);
 
   o[0] += d->rx * scale;
@@ -191,7 +191,7 @@ void distort_mask(dt_iop_module_t *self,
 void modify_roi_out(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, dt_iop_roi_t *roi_out,
                     const dt_iop_roi_t *const roi_in)
 {
-  dt_iop_rotatepixels_data_t *d = piece->data;
+  const dt_iop_rotatepixels_data_t *d = piece->data;
 
   *roi_out = *roi_in;
 
@@ -237,7 +237,7 @@ void modify_roi_in(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const d
 
   const float scale = roi_in->scale / piece->iscale;
 
-  dt_boundingbox_t aabb = { roi_out->x, roi_out->y, roi_out->x + roi_out->width, roi_out->y + roi_out->height };
+  const dt_boundingbox_t aabb = { roi_out->x, roi_out->y, roi_out->x + roi_out->width, roi_out->y + roi_out->height };
 
   dt_boundingbox_t aabb_in = { FLT_MAX, FLT_MAX, -FLT_MAX, -FLT_MAX };
 
@@ -313,15 +313,15 @@ void process(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *c
 void commit_params(dt_iop_module_t *self, dt_iop_params_t *p1, dt_dev_pixelpipe_t *pipe,
                    dt_dev_pixelpipe_iop_t *piece)
 {
-  dt_iop_rotatepixels_params_t *p = (dt_iop_rotatepixels_params_t *)p1;
+  const dt_iop_rotatepixels_params_t *p = (dt_iop_rotatepixels_params_t *)p1;
   dt_iop_rotatepixels_data_t *d = piece->data;
 
   d->rx = p->rx;
   d->ry = p->ry;
 
-  const float angle = p->angle * M_PI / 180.0f;
+  const float angle = deg2radf(p->angle);
 
-  float rt[] = { cosf(angle), sinf(angle), -sinf(angle), cosf(angle) };
+  const float rt[] = { cosf(angle), sinf(angle), -sinf(angle), cosf(angle) };
   for(int k = 0; k < 4; k++) d->m[k] = rt[k];
 
   // this should not be used for normal images
@@ -349,26 +349,6 @@ void reload_defaults(dt_iop_module_t *self)
   *d = (dt_iop_rotatepixels_params_t){ .rx = 0u, .ry = image->fuji_rotation_pos, .angle = -45.0f };
 
   self->default_enabled = ((d->rx != 0u) || (d->ry != 0u));
-
-  // FIXME: does not work.
-  self->hide_enable_button = !self->default_enabled;
-
-  if(self->widget)
-    gtk_label_set_text(GTK_LABEL(self->widget), self->default_enabled
-                       ? _("automatic pixel rotation")
-                       : _("automatic pixel rotation\nonly works for the sensors that need it."));
-}
-
-void gui_update(dt_iop_module_t *self)
-{
-}
-void gui_init(dt_iop_module_t *self)
-{
-  IOP_GUI_ALLOC(rotatepixels);
-
-  self->widget = dt_ui_label_new("");
-  gtk_label_set_line_wrap(GTK_LABEL(self->widget), TRUE);
-
 }
 
 // clang-format off
@@ -376,4 +356,3 @@ void gui_init(dt_iop_module_t *self)
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
 // clang-format on
-
