@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2012-2024 darktable developers.
+    Copyright (C) 2012-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -58,11 +58,25 @@ typedef enum dt_lib_live_view_overlay_t
 #define HANDLE_SIZE 0.02
 
 static const cairo_operator_t _overlay_modes[] = {
-  CAIRO_OPERATOR_OVER, CAIRO_OPERATOR_XOR, CAIRO_OPERATOR_ADD, CAIRO_OPERATOR_SATURATE,
-  CAIRO_OPERATOR_MULTIPLY, CAIRO_OPERATOR_SCREEN, CAIRO_OPERATOR_OVERLAY, CAIRO_OPERATOR_DARKEN,
-  CAIRO_OPERATOR_LIGHTEN, CAIRO_OPERATOR_COLOR_DODGE, CAIRO_OPERATOR_COLOR_BURN, CAIRO_OPERATOR_HARD_LIGHT,
-  CAIRO_OPERATOR_SOFT_LIGHT, CAIRO_OPERATOR_DIFFERENCE, CAIRO_OPERATOR_EXCLUSION, CAIRO_OPERATOR_HSL_HUE,
-  CAIRO_OPERATOR_HSL_SATURATION, CAIRO_OPERATOR_HSL_COLOR, CAIRO_OPERATOR_HSL_LUMINOSITY
+  CAIRO_OPERATOR_OVER,
+  CAIRO_OPERATOR_XOR,
+  CAIRO_OPERATOR_ADD,
+  CAIRO_OPERATOR_SATURATE,
+  CAIRO_OPERATOR_MULTIPLY,
+  CAIRO_OPERATOR_SCREEN,
+  CAIRO_OPERATOR_OVERLAY,
+  CAIRO_OPERATOR_DARKEN,
+  CAIRO_OPERATOR_LIGHTEN,
+  CAIRO_OPERATOR_COLOR_DODGE,
+  CAIRO_OPERATOR_COLOR_BURN,
+  CAIRO_OPERATOR_HARD_LIGHT,
+  CAIRO_OPERATOR_SOFT_LIGHT,
+  CAIRO_OPERATOR_DIFFERENCE,
+  CAIRO_OPERATOR_EXCLUSION,
+  CAIRO_OPERATOR_HSL_HUE,
+  CAIRO_OPERATOR_HSL_SATURATION,
+  CAIRO_OPERATOR_HSL_COLOR,
+  CAIRO_OPERATOR_HSL_LUMINOSITY
 };
 
 DT_MODULE(1)
@@ -81,7 +95,8 @@ typedef struct dt_lib_live_view_t
   GtkWidget *overlay, *overlay_id_box, *overlay_id, *overlay_mode, *overlay_splitline;
 } dt_lib_live_view_t;
 
-static void overlay_changed(GtkWidget *combo, dt_lib_live_view_t *lib)
+static void overlay_changed(GtkWidget *combo,
+                            dt_lib_live_view_t *lib)
 {
   int which = dt_bauhaus_combobox_get(combo);
   if(which == OVERLAY_NONE)
@@ -130,16 +145,19 @@ int position(const dt_lib_module_t *self)
 static void _rotate_ccw(GtkWidget *widget, gpointer user_data)
 {
   dt_camera_t *cam = (dt_camera_t *)darktable.camctl->active_camera;
-  cam->live_view_rotation = (cam->live_view_rotation + 1) % 4; // 0 -> 1 -> 2 -> 3 -> 0 -> ...
+  cam->live_view_rotation =
+    (cam->live_view_rotation + 1) % 4; // 0 -> 1 -> 2 -> 3 -> 0 -> ...
 }
 
 static void _rotate_cw(GtkWidget *widget, gpointer user_data)
 {
   dt_camera_t *cam = (dt_camera_t *)darktable.camctl->active_camera;
-  cam->live_view_rotation = (cam->live_view_rotation + 3) % 4; // 0 -> 3 -> 2 -> 1 -> 0 -> ...
+  cam->live_view_rotation =
+    (cam->live_view_rotation + 3) % 4; // 0 -> 3 -> 2 -> 1 -> 0 -> ...
 }
 
-// Congratulations to Simon for being the first one recognizing live view in a screen shot ^^
+// Congratulations to Simon for being the first one recognizing live
+// view in a screen shot ^^
 static void _toggle_live_view_clicked(GtkWidget *widget, gpointer user_data)
 {
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) == TRUE)
@@ -153,9 +171,10 @@ static void _toggle_live_view_clicked(GtkWidget *widget, gpointer user_data)
   }
 }
 
-// TODO: using a toggle button would be better, but this setting can also be changed by right clicking on the
-// canvas (src/views/capture.c).
-//       maybe using a signal would work? i have no idea.
+// TODO: using a toggle button would be better, but this setting can
+// also be changed by right clicking on the canvas
+// (src/views/capture.c).  maybe using a signal would work? i have no
+// idea.
 static void _zoom_live_view_clicked(GtkWidget *widget, gpointer user_data)
 {
   dt_camera_t *cam = (dt_camera_t *)darktable.camctl->active_camera;
@@ -173,9 +192,11 @@ static void _auto_focus_button_clicked(GtkWidget *widget, gpointer user_data)
 {
   const char *property = "autofocusdrive";
   CameraWidgetType property_type;
-  if(dt_camctl_camera_get_property_type(darktable.camctl, NULL, property, &property_type))
+  if(dt_camctl_camera_get_property_type(darktable.camctl, NULL,
+                                        property, &property_type))
   {
-    dt_print(DT_DEBUG_CAMCTL, "[camera control] unable to get property type for %s", property);
+    dt_print(DT_DEBUG_CAMCTL,
+             "[camera control] unable to get property type for %s", property);
   }
   else
   {
@@ -186,7 +207,9 @@ static void _auto_focus_button_clicked(GtkWidget *widget, gpointer user_data)
     else
     {
       // TODO evaluate if this is the right thing to do in default scenario
-      dt_print(DT_DEBUG_CAMCTL, "[camera control] unable to set %s for property type %d", property, property_type);
+      dt_print(DT_DEBUG_CAMCTL,
+               "[camera control] unable to set %s for property type %d",
+               property, property_type);
     }
   }
 }
@@ -195,17 +218,21 @@ static void _focus_button_clicked(GtkWidget *widget, gpointer user_data)
 {
   int focus = GPOINTER_TO_INT(user_data);
   CameraWidgetType property_type;
-  if(dt_camctl_camera_get_property_type(darktable.camctl, NULL, "manualfocusdrive", &property_type))
+  if(dt_camctl_camera_get_property_type(darktable.camctl, NULL,
+                                        "manualfocusdrive", &property_type))
   {
     // default to avoid breaking backwards compatibility
     // note that this might not work on non-Canon EOS cameras
-    dt_camctl_camera_set_property_choice(darktable.camctl, NULL, "manualfocusdrive", focus);
+    dt_camctl_camera_set_property_choice(darktable.camctl, NULL,
+                                         "manualfocusdrive", focus);
   }
   else
   {
-    // we need to check the property type here because of a peculiar difference between the property type that gphoto2
-    // supports for Canon EOS and Nikon systems. In particular, if you have a Canon, expect a TOGGLE or RADIO.
-    // If you have a Nikon, expect a RANGE.
+    // we need to check the property type here because of a peculiar
+    // difference between the property type that gphoto2 supports for
+    // Canon EOS and Nikon systems. In particular, if you have a
+    // Canon, expect a TOGGLE or RADIO.  If you have a Nikon, expect a
+    // RANGE.
     switch(property_type)
     {
       case GP_WIDGET_RANGE:
@@ -228,15 +255,19 @@ static void _focus_button_clicked(GtkWidget *widget, gpointer user_data)
           default:
             focus_amount = 0;
         }
-        dt_camctl_camera_set_property_float(darktable.camctl, NULL, "manualfocusdrive", focus_amount);
+        dt_camctl_camera_set_property_float(darktable.camctl, NULL,
+                                            "manualfocusdrive", focus_amount);
         break;
       }
       case GP_WIDGET_TOGGLE | GP_WIDGET_RADIO:
-        dt_camctl_camera_set_property_choice(darktable.camctl, NULL, "manualfocusdrive", focus);
+        dt_camctl_camera_set_property_choice(darktable.camctl, NULL,
+                                             "manualfocusdrive", focus);
         break;
       default:
         // TODO evaluate if this is the right thing to do in default scenario
-        dt_print(DT_DEBUG_CAMCTL, "[camera control] unable to set manualfocusdrive for property type %d", property_type);
+        dt_print(DT_DEBUG_CAMCTL,
+                 "[camera control] unable to set manualfocusdrive for property type %d",
+                 property_type);
         break;
     }
   }
@@ -245,24 +276,28 @@ static void _focus_button_clicked(GtkWidget *widget, gpointer user_data)
 static void _toggle_flip_clicked(GtkWidget *widget, gpointer user_data)
 {
   dt_camera_t *cam = (dt_camera_t *)darktable.camctl->active_camera;
+
   cam->live_view_flip = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 }
 
 static void _overlay_id_changed(GtkWidget *widget, gpointer user_data)
 {
   dt_lib_live_view_t *lib = (dt_lib_live_view_t *)user_data;
+
   lib->imgid = gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget));
   dt_conf_set_int("plugins/lighttable/live_view/overlay_imgid", lib->imgid);
 }
 
 static void _overlay_mode_changed(GtkWidget *combo, gpointer user_data)
 {
-  dt_conf_set_int("plugins/lighttable/live_view/overlay_mode", dt_bauhaus_combobox_get(combo));
+  dt_conf_set_int("plugins/lighttable/live_view/overlay_mode",
+                  dt_bauhaus_combobox_get(combo));
 }
 
 static void _overlay_splitline_changed(GtkWidget *combo, gpointer user_data)
 {
-  dt_conf_set_int("plugins/lighttable/live_view/splitline", dt_bauhaus_combobox_get(combo));
+  dt_conf_set_int("plugins/lighttable/live_view/splitline",
+                  dt_bauhaus_combobox_get(combo));
 }
 
 void gui_init(dt_lib_module_t *self)
@@ -286,23 +321,46 @@ void gui_init(dt_lib_module_t *self)
   g_signal_connect(G_OBJECT(button), "clicked", G_CALLBACK(callback), data); \
   dt_action_define(DT_ACTION(self), NULL, action, button, *(#type)?&dt_action_def_toggle:&dt_action_def_button);
 
-  lib->live_view = NEW_BUTTON(toggle, dtgtk_cairo_paint_eye, 0, _toggle_live_view_clicked, lib, N_("toggle live view"));
-  dt_shortcut_register(dt_action_section(DT_ACTION(self), N_("toggle live view")), 0, 0, GDK_KEY_v, 0);
-  lib->live_view_zoom = NEW_BUTTON(, dtgtk_cairo_paint_zoom, 0, _zoom_live_view_clicked, lib, N_("zoom live view")); // TODO: see _zoom_live_view_clicked
-  dt_shortcut_register(dt_action_section(DT_ACTION(self), N_("zoom live view")), 0, 0, GDK_KEY_w, 0);
-  lib->rotate_ccw = NEW_BUTTON(, dtgtk_cairo_paint_refresh, 0, _rotate_ccw, lib, N_("rotate 90 degrees CCW"));
-  lib->rotate_cw = NEW_BUTTON(,dtgtk_cairo_paint_refresh, CPF_DIRECTION_UP, _rotate_cw, lib, N_("rotate 90 degrees CW"));
-  lib->flip = NEW_BUTTON(toggle, dtgtk_cairo_paint_flip, CPF_DIRECTION_UP, _toggle_flip_clicked, lib, N_("flip live view horizontally"));
+  lib->live_view = NEW_BUTTON(toggle, dtgtk_cairo_paint_eye, 0,
+                              _toggle_live_view_clicked, lib, N_("toggle live view"));
+  dt_shortcut_register(dt_action_section(DT_ACTION(self),
+                                         N_("toggle live view")), 0, 0, GDK_KEY_v, 0);
+  lib->live_view_zoom = NEW_BUTTON(, dtgtk_cairo_paint_zoom, 0,
+                                   _zoom_live_view_clicked, lib,
+                                   N_("zoom live view")); // TODO: see _zoom_live_view_clicked
+  dt_shortcut_register(dt_action_section(DT_ACTION(self),
+                                         N_("zoom live view")), 0, 0, GDK_KEY_w, 0);
+  lib->rotate_ccw = NEW_BUTTON(, dtgtk_cairo_paint_refresh, 0,
+                               _rotate_ccw, lib, N_("rotate 90 degrees CCW"));
+  lib->rotate_cw = NEW_BUTTON(,dtgtk_cairo_paint_refresh, CPF_DIRECTION_UP,
+                              _rotate_cw, lib, N_("rotate 90 degrees CW"));
+  lib->flip = NEW_BUTTON(toggle, dtgtk_cairo_paint_flip, CPF_DIRECTION_UP,
+                         _toggle_flip_clicked, lib, N_("flip live view horizontally"));
 
   // focus buttons
   box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start(GTK_BOX(self->widget), box, TRUE, TRUE, 0);
 
-  lib->focus_in_big = NEW_BUTTON(,dtgtk_cairo_paint_solid_triangle, CPF_DIRECTION_LEFT, _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_NEARER), N_("move focus point in (big steps)"));
-  lib->focus_in_small = NEW_BUTTON(,dtgtk_cairo_paint_arrow, CPF_DIRECTION_LEFT, _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_NEAR), N_("move focus point in (small steps)"));// TODO icon not centered
-  lib->auto_focus = NEW_BUTTON(,dtgtk_cairo_paint_lock, 0, _auto_focus_button_clicked, GINT_TO_POINTER(1), N_("run autofocus"));
-  lib->focus_out_small = NEW_BUTTON(,dtgtk_cairo_paint_arrow, CPF_DIRECTION_RIGHT, _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_FAR), N_("move focus point out (small steps)")); // TODO same here
-  lib->focus_out_big = NEW_BUTTON(,dtgtk_cairo_paint_solid_triangle, CPF_DIRECTION_RIGHT, _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_FARTHER), N_("move focus point out (big steps)"));
+  lib->focus_in_big = NEW_BUTTON(,dtgtk_cairo_paint_solid_triangle,
+                                 CPF_DIRECTION_LEFT,
+                                 _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_NEARER),
+                                 N_("move focus point in (big steps)"));
+  lib->focus_in_small = NEW_BUTTON(,dtgtk_cairo_paint_arrow,
+                                   CPF_DIRECTION_LEFT,
+                                   _focus_button_clicked, GINT_TO_POINTER(DT_FOCUS_NEAR),
+                                   N_("move focus point in (small steps)"));// TODO icon not centered
+  lib->auto_focus = NEW_BUTTON(,dtgtk_cairo_paint_lock, 0,
+                               _auto_focus_button_clicked, GINT_TO_POINTER(1),
+                               N_("run autofocus"));
+  lib->focus_out_small = NEW_BUTTON(,dtgtk_cairo_paint_arrow, CPF_DIRECTION_RIGHT,
+                                    _focus_button_clicked,
+                                    GINT_TO_POINTER(DT_FOCUS_FAR),
+                                    N_("move focus point out (small steps)")); // TODO same here
+  lib->focus_out_big = NEW_BUTTON(,dtgtk_cairo_paint_solid_triangle,
+                                  CPF_DIRECTION_RIGHT,
+                                  _focus_button_clicked,
+                                  GINT_TO_POINTER(DT_FOCUS_FARTHER),
+                                  N_("move focus point out (big steps)"));
 #undef NEW_BUTTON
 
   lib->overlay = dt_bauhaus_combobox_new_action(DT_ACTION(self));
@@ -312,7 +370,8 @@ void gui_init(dt_lib_module_t *self)
   dt_bauhaus_combobox_add(lib->overlay, _("selected image"));
   dt_bauhaus_combobox_add(lib->overlay, _("id"));
   gtk_widget_set_tooltip_text(lib->overlay, _("overlay another image over the live view"));
-  g_signal_connect(G_OBJECT(lib->overlay), "value-changed", G_CALLBACK(overlay_changed), lib);
+  g_signal_connect(G_OBJECT(lib->overlay), "value-changed",
+                   G_CALLBACK(overlay_changed), lib);
   gtk_box_pack_start(GTK_BOX(self->widget), lib->overlay, TRUE, TRUE, 0);
 
   lib->overlay_id_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
@@ -320,8 +379,10 @@ void gui_init(dt_lib_module_t *self)
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   lib->overlay_id = gtk_spin_button_new_with_range(0, 1000000000, 1);
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(lib->overlay_id), 0);
-  gtk_widget_set_tooltip_text(lib->overlay_id, _("enter image id of the overlay manually"));
-  g_signal_connect(G_OBJECT(lib->overlay_id), "value-changed", G_CALLBACK(_overlay_id_changed), lib);
+  gtk_widget_set_tooltip_text(lib->overlay_id,
+                              _("enter image id of the overlay manually"));
+  g_signal_connect(G_OBJECT(lib->overlay_id), "value-changed",
+                   G_CALLBACK(_overlay_id_changed), lib);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(lib->overlay_id),
                             dt_conf_get_int("plugins/lighttable/live_view/overlay_imgid"));
   gtk_box_pack_start(GTK_BOX(lib->overlay_id_box), label, TRUE, TRUE, 0);
@@ -352,8 +413,10 @@ void gui_init(dt_lib_module_t *self)
   dt_bauhaus_combobox_add(lib->overlay_mode, C_("blendmode", "HSL color"));
   dt_bauhaus_combobox_add(lib->overlay_mode, C_("blendmode", "HSL luminosity"));
   gtk_widget_set_tooltip_text(lib->overlay_mode, _("mode of the overlay"));
-  dt_bauhaus_combobox_set(lib->overlay_mode, dt_conf_get_int("plugins/lighttable/live_view/overlay_mode"));
-  g_signal_connect(G_OBJECT(lib->overlay_mode), "value-changed", G_CALLBACK(_overlay_mode_changed), lib);
+  dt_bauhaus_combobox_set(lib->overlay_mode,
+                          dt_conf_get_int("plugins/lighttable/live_view/overlay_mode"));
+  g_signal_connect(G_OBJECT(lib->overlay_mode), "value-changed",
+                   G_CALLBACK(_overlay_mode_changed), lib);
   gtk_box_pack_start(GTK_BOX(self->widget), lib->overlay_mode, TRUE, TRUE, 0);
 
   lib->overlay_splitline = dt_bauhaus_combobox_new_action(DT_ACTION(self));
@@ -361,8 +424,10 @@ void gui_init(dt_lib_module_t *self)
   dt_bauhaus_combobox_add(lib->overlay_splitline, _("off"));
   dt_bauhaus_combobox_add(lib->overlay_splitline, _("on"));
   gtk_widget_set_tooltip_text(lib->overlay_splitline, _("only draw part of the overlay"));
-  dt_bauhaus_combobox_set(lib->overlay_splitline, dt_conf_get_int("plugins/lighttable/live_view/splitline"));
-  g_signal_connect(G_OBJECT(lib->overlay_splitline), "value-changed", G_CALLBACK(_overlay_splitline_changed),
+  dt_bauhaus_combobox_set(lib->overlay_splitline,
+                          dt_conf_get_int("plugins/lighttable/live_view/splitline"));
+  g_signal_connect(G_OBJECT(lib->overlay_splitline), "value-changed",
+                   G_CALLBACK(_overlay_splitline_changed),
                    lib);
   gtk_box_pack_start(GTK_BOX(self->widget), lib->overlay_splitline, TRUE, TRUE, 0);
 
@@ -386,11 +451,13 @@ void gui_cleanup(dt_lib_module_t *self)
   self->data = NULL;
 }
 
-void view_enter(struct dt_lib_module_t *self,struct dt_view_t *old_view,struct dt_view_t *new_view)
+void view_enter(dt_lib_module_t *self,
+                dt_view_t *old_view,
+                dt_view_t *new_view)
 {
   // disable buttons that won't work with this camera
-  // TODO: initialize tethering mode outside of libs/camera.s so we can use darktable.camctl->active_camera
-  // here
+  // TODO: initialize tethering mode outside of libs/camera.s so we
+  // can use darktable.camctl->active_camera here
   const dt_lib_live_view_t *lib = self->data;
   const dt_camera_t *cam = darktable.camctl->active_camera;
   if(cam == NULL) cam = darktable.camctl->wanted_camera;
@@ -404,7 +471,9 @@ void view_enter(struct dt_lib_module_t *self,struct dt_view_t *old_view,struct d
   gtk_widget_set_sensitive(lib->focus_out_small, sensitive);
 }
 
-void view_leave(struct dt_lib_module_t *self, struct dt_view_t *old_view, struct dt_view_t *new_view)
+void view_leave(dt_lib_module_t *self,
+                dt_view_t *old_view,
+                dt_view_t *new_view)
 {
   const dt_lib_live_view_t *lib = self->data;
 
@@ -422,11 +491,17 @@ void view_leave(struct dt_lib_module_t *self, struct dt_view_t *old_view, struct
 // TODO: find out where the zoom window is and draw overlay + grid accordingly
 #define MARGIN 20
 #define BAR_HEIGHT 18 /* see libs/camera.c */
-void gui_post_expose(dt_lib_module_t *self, cairo_t *cr, int32_t width, int32_t height, int32_t pointerx,
-                     int32_t pointery)
+void gui_post_expose(dt_lib_module_t *self,
+                     cairo_t *cr,
+                     const int32_t width,
+                     const int32_t height,
+                     const int32_t pointerx,
+                     const int32_t pointery)
 {
   dt_camera_t *cam = (dt_camera_t *)darktable.camctl->active_camera;
+  if (!cam) return;
   dt_lib_live_view_t *lib = self->data;
+  if (!lib) return;
 
   if(cam->is_live_viewing == FALSE || cam->live_view_zoom == TRUE) return;
 
@@ -525,10 +600,10 @@ void gui_post_expose(dt_lib_module_t *self, cairo_t *cr, int32_t width, int32_t
       }
 
       cairo_set_source_surface(cr, surface, 0, 0);
-      // set filter no nearest:
-      // in skull/error mode, we want to see big pixels.
-      // in 1 iir mode for the right mip, we want to see exactly what the pipe gave us, 1:1 pixel for pixel.
-      // in between, filtering just makes stuff go unsharp.
+      // set filter no nearest: in skull/error mode, we want to see
+      // big pixels.  in 1 iir mode for the right mip, we want to see
+      // exactly what the pipe gave us, 1:1 pixel for pixel.  in
+      // between, filtering just makes stuff go unsharp.
       if((buf.width <= 30 && buf.height <= 30) || fabsf(scale - 1.0f) < 0.01f)
         cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_NEAREST);
       cairo_rectangle(cr, 0, 0, buf.width, buf.height);
@@ -581,7 +656,8 @@ void gui_post_expose(dt_lib_module_t *self, cairo_t *cr, int32_t width, int32_t
       cairo_line_to(cr, x1, y1);
       cairo_stroke(cr);
 
-      /* if mouse over control lets draw center rotate control, hide if split is dragged */
+      /* if mouse over control lets draw center rotate control, hide
+       * if split is dragged */
       if(!lib->splitline_dragging && mouse_over_control)
       {
         cairo_set_line_width(cr, 0.5);
@@ -621,7 +697,11 @@ void gui_post_expose(dt_lib_module_t *self, cairo_t *cr, int32_t width, int32_t
   dt_pthread_mutex_unlock(&cam->live_view_buffer_mutex);
 }
 
-int button_released(struct dt_lib_module_t *self, double x, double y, int which, uint32_t state)
+int button_released(dt_lib_module_t *self,
+                    const double x,
+                    const double y,
+                    const int which,
+                    const uint32_t state)
 {
   dt_lib_live_view_t *d = self->data;
   if(d->splitline_dragging == TRUE)
@@ -632,8 +712,13 @@ int button_released(struct dt_lib_module_t *self, double x, double y, int which,
   return 0;
 }
 
-int button_pressed(struct dt_lib_module_t *self, double x, double y, double pressure, int which, int type,
-                   uint32_t state)
+int button_pressed(dt_lib_module_t *self,
+                   const double x,
+                   const double y,
+                   const double pressure,
+                   const int which,
+                   const int type,
+                   const uint32_t state)
 {
   dt_lib_live_view_t *lib = self->data;
   int result = 0;
@@ -649,7 +734,8 @@ int button_pressed(struct dt_lib_module_t *self, double x, double y, double pres
       break;
   }
 
-  if(dt_is_valid_imgid(imgid) && dt_bauhaus_combobox_get(lib->overlay_splitline))
+  if(dt_is_valid_imgid(imgid)
+     && dt_bauhaus_combobox_get(lib->overlay_splitline))
   {
     const double width = lib->overlay_x1 - lib->overlay_x0;
     const double height = lib->overlay_y1 - lib->overlay_y0;
@@ -682,7 +768,11 @@ int button_pressed(struct dt_lib_module_t *self, double x, double y, double pres
   return result;
 }
 
-int mouse_moved(dt_lib_module_t *self, double x, double y, double pressure, int which)
+int mouse_moved(dt_lib_module_t *self,
+                const double x,
+                const double y,
+                const double pressure,
+                const int which)
 {
   dt_lib_live_view_t *lib = self->data;
   int result = 0;
