@@ -173,8 +173,7 @@ static void _locations_tree_update(dt_lib_module_t *self, const guint locid)
           dt_util_str_cat(&pth, "%s|", *token);
           gchar *pth2 = g_strdup(pth);
           pth2[strlen(pth2) - 1] = '\0';
-          gtk_tree_store_insert(GTK_TREE_STORE(model), &iter, common_length > 0 ? &parent : NULL, -1);
-          gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
+          gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, common_length > 0 ? &parent : NULL, -1,
                             DT_MAP_LOCATION_COL_TAG, *token,
                             DT_MAP_LOCATION_COL_ID, (token == &tokens[tokens_length-1]) ?
                                                      ((dt_map_location_t *)stag->data)->id : 0,
@@ -293,8 +292,7 @@ static void _new_button_clicked(GtkButton *button, dt_lib_module_t *self)
   }
 
   // add the new record to the tree
-  gtk_tree_store_insert(GTK_TREE_STORE(model), &iter, path ? &parent : NULL, -1);
-  gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
+  gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, path ? &parent : NULL, -1,
                      DT_MAP_LOCATION_COL_TAG, &new_name[base_len],
                      DT_MAP_LOCATION_COL_ID, -1,
                      DT_MAP_LOCATION_COL_PATH, new_name,
