@@ -47,10 +47,9 @@ const char *name(dt_lib_module_t *self)
   return _("session");
 }
 
-const char **views(dt_lib_module_t *self)
+dt_view_type_flags_t views(dt_lib_module_t *self)
 {
-  static const char *v[] = {"tethering", NULL};
-  return v;
+  return DT_VIEW_TETHERING;
 }
 
 uint32_t container(dt_lib_module_t *self)
@@ -68,9 +67,8 @@ int position(const dt_lib_module_t *self)
   return 999;
 }
 
-static void create_callback(GtkButton *button, gpointer user_data)
+static void create_callback(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_module_t *self = (dt_lib_module_t *)user_data;
   dt_lib_session_t *lib = self->data;
 
   dt_conf_set_string("plugins/session/jobcode", gtk_entry_get_text(lib->gui.entry1));
@@ -100,8 +98,7 @@ void gui_init(dt_lib_module_t *self)
   gtk_widget_set_halign(GTK_WIDGET(lib->gui.label1), GTK_ALIGN_START);
   gtk_box_pack_start(vbox1, GTK_WIDGET(lib->gui.label1), TRUE, TRUE, 0);
 
-  lib->gui.entry1 = GTK_ENTRY(gtk_entry_new());
-  gtk_entry_set_width_chars(GTK_ENTRY(lib->gui.entry1), 0);
+  lib->gui.entry1 = GTK_ENTRY(dt_ui_entry_new(0));
   gtk_box_pack_start(vbox2, GTK_WIDGET(lib->gui.entry1), TRUE, TRUE, 0);
 
   lib->gui.button1 = GTK_BUTTON(gtk_button_new_with_label(_("create")));
