@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2010-2024 darktable developers.
+    Copyright (C) 2010-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 #include "common/utility.h"
 #include "control/conf.h"
 #include "control/control.h"
-#include "control/jobs.h"
-#include "dtgtk/button.h"
 #include "gui/accelerators.h"
 #include "gui/gtk.h"
 #include "gui/styles.h"
@@ -271,7 +269,11 @@ GList* _get_selected_style_names(GList* selected_styles, GtkTreeModel *model)
     gtk_tree_model_get_iter(model, &iter, (GtkTreePath *)style->data);
     gtk_tree_model_get_value(model, &iter, DT_STYLES_COL_FULLNAME, &value);
     if(G_VALUE_HOLDS_STRING(&value))
-      style_names = g_list_prepend(style_names, g_strdup(g_value_get_string(&value)));
+    {
+      gchar *vstring = g_strdup(g_value_get_string(&value));
+      if(vstring)
+        style_names = g_list_prepend(style_names, vstring);
+    }
     g_value_unset(&value);
   }
   return g_list_reverse(style_names); // list was built in reverse order, so un-reverse it
@@ -303,6 +305,7 @@ static void _apply_clicked(GtkWidget *w, dt_lib_styles_t *d)
   }
   else
   {
+    dt_stop_backthumbs_crawler(FALSE);
     GList *imgs = dt_act_on_get_images(TRUE, TRUE, FALSE);
     if(!g_list_is_empty(imgs))
     {
@@ -312,6 +315,8 @@ static void _apply_clicked(GtkWidget *w, dt_lib_styles_t *d)
     }
     else
       g_list_free_full(style_names, g_free);
+
+    dt_start_backthumbs_crawler();
   }
 }
 
@@ -393,7 +398,7 @@ gboolean _ask_before_delete_style(const gint style_cnt)
 {
   return !dt_conf_get_bool("plugins/lighttable/style/ask_before_delete_style")
     || dt_gui_show_yes_no_dialog(
-      ngettext("remove style?", "remove styles?", style_cnt),
+      ngettext("remove style?", "remove styles?", style_cnt), "",
       ngettext("do you really want to remove %d style?",
                "do you really want to remove %d styles?", style_cnt),
       style_cnt);
@@ -487,8 +492,6 @@ static void _export_clicked(GtkWidget *w, dt_lib_styles_t *d)
         else
         {
           /* create and run dialog */
-          char overwrite_str[256];
-
           gint overwrite_dialog_res = GTK_RESPONSE_ACCEPT;
           gint overwrite_dialog_check_button_res = TRUE;
 
@@ -504,16 +507,13 @@ static void _export_clicked(GtkWidget *w, dt_lib_styles_t *d)
                                             GTK_RESPONSE_CANCEL);
 
             // contents for dialog
-            GtkWidget *content_area =
-              gtk_dialog_get_content_area(GTK_DIALOG(dialog_overwrite_export));
-            sprintf(overwrite_str, _("style `%s' already exists.\ndo you want to overwrite existing style?\n"), stylename);
-            GtkWidget *label = gtk_label_new(overwrite_str);
+            gchar *overwrite_str = g_strdup_printf(_("style `%s' already exists.\ndo you want to overwrite existing style?\n"), stylename);
             GtkWidget *overwrite_dialog_check_button =
               gtk_check_button_new_with_label(_("apply this option to all existing styles"));
 
-            gtk_container_add(GTK_CONTAINER(content_area), label);
-            gtk_container_add(GTK_CONTAINER(content_area), overwrite_dialog_check_button);
+            dt_gui_dialog_add(GTK_DIALOG(dialog_overwrite_export), gtk_label_new(overwrite_str), overwrite_dialog_check_button);
             gtk_widget_show_all(dialog_overwrite_export);
+            g_free(overwrite_str);
 
             // disable check button and skip button when only one style is selected
             if(g_list_is_singleton(style_names))
@@ -645,8 +645,6 @@ static void _import_clicked(GtkWidget *w, dt_lib_styles_t *d)
         else
         {
           /* create and run dialog */
-          char overwrite_str[256];
-
           gint overwrite_dialog_res = GTK_RESPONSE_ACCEPT;
           gint overwrite_dialog_check_button_res = TRUE;
 
@@ -661,14 +659,11 @@ static void _import_clicked(GtkWidget *w, dt_lib_styles_t *d)
             gtk_dialog_set_default_response(GTK_DIALOG(dialog_overwrite_import), GTK_RESPONSE_CANCEL);
 
             // contents for dialog
-            GtkWidget *content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog_overwrite_import));
-            sprintf(overwrite_str, _("style `%s' already exists.\ndo you want to overwrite existing style?\n"), bname);
-            GtkWidget *label = gtk_label_new(overwrite_str);
+            gchar *overwrite_str = g_strdup_printf(_("style `%s' already exists.\ndo you want to overwrite existing style?\n"), bname);
             GtkWidget *overwrite_dialog_check_button = gtk_check_button_new_with_label(_("apply this option to all existing styles"));
-
-            gtk_container_add(GTK_CONTAINER(content_area), label);
-            gtk_container_add(GTK_CONTAINER(content_area), overwrite_dialog_check_button);
+            dt_gui_dialog_add(GTK_DIALOG(dialog_overwrite_import), gtk_label_new(overwrite_str), overwrite_dialog_check_button);
             gtk_widget_show_all(dialog_overwrite_import);
+            g_free(overwrite_str);
 
             // disable check button and skip button when dealing with one style
             if(g_list_is_singleton(filenames))
@@ -782,7 +777,12 @@ void gui_update(dt_lib_module_t *self)
   const gboolean has_act_on = dt_act_on_get_images_nb(TRUE, FALSE) > 0;
 
   GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(d->tree));
-  const gboolean any_style = gtk_tree_selection_count_selected_rows(selection) > 0;
+  GtkTreeModel *model= gtk_tree_view_get_model(d->tree);
+  GList *selected_styles = gtk_tree_selection_get_selected_rows(selection, &model);
+  GList *style_names = _get_selected_style_names(selected_styles, model);
+  const gboolean any_style = style_names != NULL;
+  g_list_free_full(style_names, g_free);
+  g_list_free_full(selected_styles, (GDestroyNotify) gtk_tree_path_free);
 
   gtk_widget_set_sensitive(GTK_WIDGET(d->create_button), has_act_on);
   gtk_widget_set_sensitive(GTK_WIDGET(d->edit_button), any_style);
