@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2011-2021 darktable developers.
+    Copyright (C) 2011-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,9 @@
 DT_MODULE(1)
 
 /* proxy function, to add a widget to toolbox */
-static void _lib_module_toolbox_add(dt_lib_module_t *self, GtkWidget *widget, dt_view_type_flags_t views);
+static void _lib_module_toolbox_add(dt_lib_module_t *self,
+                                    GtkWidget *widget,
+                                    dt_view_type_flags_t views);
 
 
 typedef struct child_data_t
@@ -89,10 +91,13 @@ void gui_cleanup(dt_lib_module_t *self)
   self->data = NULL;
 }
 
-void view_enter(dt_lib_module_t *self, dt_view_t *old_view, dt_view_t *new_view)
+void view_enter(dt_lib_module_t *self,
+                dt_view_t *old_view,
+                dt_view_t *new_view)
 {
   dt_lib_module_toolbox_t *d = self->data;
   dt_view_type_flags_t nv= new_view->view(new_view);
+  gtk_widget_set_no_show_all(d->container, TRUE);
   for(const GList *child_elt = d->child_views; child_elt; child_elt = g_list_next(child_elt))
   {
     child_data_t* child_data = child_elt->data;
@@ -107,7 +112,9 @@ void view_enter(dt_lib_module_t *self, dt_view_t *old_view, dt_view_t *new_view)
   }
 }
 
-static void _lib_module_toolbox_add(dt_lib_module_t *self, GtkWidget *widget, dt_view_type_flags_t views)
+static void _lib_module_toolbox_add(dt_lib_module_t *self,
+                                    GtkWidget *widget,
+                                    dt_view_type_flags_t views)
 {
   dt_lib_module_toolbox_t *d = self->data;
   gtk_box_pack_start(GTK_BOX(d->container), widget, TRUE, FALSE, 0);
