@@ -48,7 +48,9 @@ static int label_member(lua_State *L)
   if(lua_gettop(L) > 2) {
     char tmp[256];
     luaA_to(L,char_256,&tmp,3);
-    dt_bauhaus_widget_set_label(slider->widget,NULL,tmp);
+    lua_getglobal(L, "script_manager_running_script");
+    dt_bauhaus_widget_set_module(slider->widget, &darktable.control->actions_lua);
+    dt_bauhaus_widget_set_label(slider->widget,lua_tolstring(L,-1,NULL),tmp);
     return 0;
   }
   lua_pushstring(L,dt_bauhaus_widget_get_label(slider->widget));
