@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2009-2024 darktable developers.
+    Copyright (C) 2009-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ void dt_view_manager_cleanup(dt_view_manager_t *vm)
   vm->views = NULL;
 }
 
-const dt_view_t *dt_view_manager_get_current_view(dt_view_manager_t *vm)
+const dt_view_t *dt_view_manager_get_current_view(const dt_view_manager_t *vm)
 {
   return vm->current_view;
 }
@@ -244,9 +244,6 @@ gboolean dt_view_manager_switch_by_view(dt_view_manager_t *vm,
       && dt_view_get_current() == DT_VIEW_DARKROOM)
     return FALSE;
 
-  // reset the cursor to the default one
-  dt_control_change_cursor(GDK_LEFT_PTR);
-
   dt_set_backthumb_time(0.0);
 
   // destroy old module list
@@ -308,6 +305,11 @@ gboolean dt_view_manager_switch_by_view(dt_view_manager_t *vm,
     }
   }
 
+  // show we are busy changing views
+  dt_control_change_cursor(GDK_WATCH);
+  if(new_view != old_view)
+    dt_gui_process_events();
+
   /* cleanup current view before initialization of new  */
   if(old_view)
   {
@@ -381,7 +383,7 @@ gboolean dt_view_manager_switch_by_view(dt_view_manager_t *vm,
       char var[1024];
       snprintf(var, sizeof(var), "plugins/%s/%s/expanded",
                new_view->module_name, plugin->plugin_name);
-      gboolean expanded = dt_conf_get_bool(var);
+      const gboolean expanded = dt_conf_get_bool(var);
       dt_lib_gui_set_expanded(plugin, expanded);
       dt_lib_set_visible(plugin, TRUE);
     }
@@ -438,10 +440,14 @@ gboolean dt_view_manager_switch_by_view(dt_view_manager_t *vm,
 
   // update toast visibility
   DT_CONTROL_SIGNAL_RAISE(DT_SIGNAL_CONTROL_TOAST_REDRAW);
+
+  // reset the cursor to the default one
+  dt_control_change_cursor(GDK_LEFT_PTR);
+
   return FALSE;
 }
 
-const char *dt_view_manager_name(dt_view_manager_t *vm)
+const char *dt_view_manager_name(const dt_view_manager_t *vm)
 {
   if(!vm->current_view)
     return "";
@@ -1089,7 +1095,7 @@ void dt_view_active_images_reset(const gboolean raise)
   if(raise)
     DT_CONTROL_SIGNAL_RAISE(DT_SIGNAL_ACTIVE_IMAGES_CHANGE);
 }
-void dt_view_active_images_add(dt_imgid_t imgid, gboolean raise)
+void dt_view_active_images_add(const dt_imgid_t imgid, const gboolean raise)
 {
   darktable.view_manager->active_images =
     g_slist_append(darktable.view_manager->active_images, GINT_TO_POINTER(imgid));
@@ -1117,7 +1123,7 @@ void dt_view_manager_module_toolbox_add(dt_view_manager_t *vm,
     vm->proxy.module_toolbox.add(vm->proxy.module_toolbox.module, tool, views);
 }
 
-dt_darkroom_layout_t dt_view_darkroom_get_layout(dt_view_manager_t *vm)
+dt_darkroom_layout_t dt_view_darkroom_get_layout(const dt_view_manager_t *vm)
 {
   if(vm->proxy.darkroom.view)
     return vm->proxy.darkroom.get_layout(vm->proxy.darkroom.view);
@@ -1132,7 +1138,7 @@ void dt_view_lighttable_set_zoom(dt_view_manager_t *vm,
     vm->proxy.lighttable.set_zoom(vm->proxy.lighttable.module, zoom);
 }
 
-gint dt_view_lighttable_get_zoom(dt_view_manager_t *vm)
+gint dt_view_lighttable_get_zoom(const dt_view_manager_t *vm)
 {
   if(vm->proxy.lighttable.module)
     return vm->proxy.lighttable.get_zoom(vm->proxy.lighttable.module);
@@ -1482,8 +1488,6 @@ void dt_view_accels_show(dt_view_manager_t *vm)
 #endif
   dt_gui_add_class(vm->accels_window.window, "dt_accels_window");
 
-  GtkWidget *sw = gtk_scrolled_window_new(NULL, NULL);
-
   GtkWidget *hb = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
 
   vm->accels_window.flow_box = gtk_flow_box_new();
@@ -1508,10 +1512,9 @@ void dt_view_accels_show(dt_view_manager_t *vm)
 
   GtkAllocation alloc;
   gtk_widget_get_allocation(dt_ui_main_window(darktable.gui->ui), &alloc);
-  // gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), alloc.height);
+  GtkWidget *sw = dt_gui_scroll_wrap(hb);
   gtk_scrolled_window_set_max_content_height(GTK_SCROLLED_WINDOW(sw), alloc.height);
   gtk_scrolled_window_set_max_content_width(GTK_SCROLLED_WINDOW(sw), alloc.width);
-  gtk_container_add(GTK_CONTAINER(sw), hb);
   gtk_container_add(GTK_CONTAINER(vm->accels_window.window), sw);
 
   gtk_window_set_resizable(GTK_WINDOW(vm->accels_window.window), FALSE);
@@ -1686,6 +1689,35 @@ void dt_view_audio_stop(dt_view_manager_t *vm)
   vm->audio.audio_player_id = -1;
 }
 
+static void _match_rotation(cairo_t *cr,
+                            dt_dev_zoom_pos_t d,
+                            double dx,
+                            double dy,
+                            const double cx,
+                            const double cy)
+{
+  const double xx = d[2] - d[0];
+  const double yx = d[3] - d[1];
+  const double xy = d[4] - d[0];
+  const double yy = d[5] - d[1];
+
+  if(fabs(xx * yy - xy * yx) < 1e-10)
+    return;
+
+  const double sx = hypot(xx, yx);
+  const double sy = hypot(xy, yy);
+  cairo_matrix_t matrix;
+  cairo_matrix_init(&matrix, xx / sx, yx / sx, xy / sy, yy / sy, 0, 0);
+  cairo_transform(cr, &matrix);
+
+  dx += 0.5 * cx;
+  dy += 0.5 * cy;
+
+  cairo_matrix_invert(&matrix);
+  cairo_matrix_transform_point(&matrix, &dx, &dy);
+  cairo_translate(cr, dx - 0.5 * cx, dy - 0.5 * cy);
+}
+
 void dt_view_paint_surface(cairo_t *cr,
                            const size_t width,
                            const size_t height,
@@ -1695,33 +1727,34 @@ void dt_view_paint_surface(cairo_t *cr,
                            float buf_scale,
                            int buf_width,
                            int buf_height,
-                           float buf_zoom_x,
-                           float buf_zoom_y)
+                           dt_dev_zoom_pos_t buf_zoom_pos)
 {
   dt_develop_t *dev = darktable.develop;
+  dt_dev_pixelpipe_t *pp = dev->preview_pipe;
 
   int processed_width, processed_height;
   dt_dev_get_processed_size(port, &processed_width, &processed_height);
   if(!processed_width || !processed_height)
     return;
 
-  float pts[] = { buf_zoom_x, buf_zoom_y,
-                  dev->preview_pipe->backbuf_zoom_x, dev->preview_pipe->backbuf_zoom_y,
-                  port->zoom_x, port->zoom_y };
-  dt_dev_distort_transform_plus(dev, port->pipe, 0.0f, DT_DEV_TRANSFORM_DIR_ALL, pts, 3);
+  float pts[14];
+  memcpy(pts, buf_zoom_pos, sizeof(dt_dev_zoom_pos_t));
+  memcpy(pts + 6, pp->backbuf_zoom_pos, sizeof(dt_dev_zoom_pos_t));
+  pts[12] = port->zoom_x; pts[13] = port->zoom_y;
+  dt_dev_distort_transform_plus(dev, port->pipe, 0.0f, DT_DEV_TRANSFORM_DIR_ALL_GEOMETRY, pts, 7);
 
-  float offset_x  = pts[0] / processed_width  - 0.5f;
-  float offset_y  = pts[1] / processed_height - 0.5f;
-  float preview_x = pts[2] / processed_width  - 0.5f;
-  float preview_y = pts[3] / processed_height - 0.5f;
-  float zoom_x    = pts[4] / processed_width  - 0.5f;
-  float zoom_y    = pts[5] / processed_height - 0.5f;
+  const float offset_x  = pts[0] / processed_width  - 0.5f;
+  const float offset_y  = pts[1] / processed_height - 0.5f;
+  const float preview_x = pts[6] / processed_width  - 0.5f;
+  const float preview_y = pts[7] / processed_height - 0.5f;
+  const float zoom_x    = pts[12]/ processed_width  - 0.5f;
+  const float zoom_y    = pts[13]/ processed_height - 0.5f;
 
-  dt_dev_zoom_t zoom = port->zoom;
-  int closeup = port->closeup;
+  const dt_dev_zoom_t zoom = port->zoom;
+  const int closeup = port->closeup;
   const float ppd           = port->ppd;
   const double tb           = port->border_size;
-  const float zoom_scale    = dt_dev_get_zoom_scale(port, zoom, 1<<closeup, 1);
+  const float zoom_scale    = dt_dev_get_zoom_scale(port, zoom, 1<<closeup, TRUE);
   const float backbuf_scale = dt_dev_get_zoom_scale(port, zoom, 1.0f, 0) * ppd;
 
   dt_print_pipe(DT_DEBUG_EXPOSE,
@@ -1750,8 +1783,7 @@ void dt_view_paint_surface(cairo_t *cr,
   cairo_paint(cr);
 
   cairo_translate(cr, 0.5 * width, 0.5 * height);
-
-  dt_pthread_mutex_lock(&dev->preview_pipe->backbuf_mutex);
+  dt_pthread_mutex_lock(&pp->backbuf_mutex);
 
   const int maxw = MIN(port->width, backbuf_scale * processed_width * (1<<closeup) / ppd);
   const int maxh = MIN(port->height, backbuf_scale * processed_height * (1<<closeup) / ppd);
@@ -1770,52 +1802,51 @@ void dt_view_paint_surface(cairo_t *cr,
 
   cairo_rectangle(cr, -0.5 * maxw, -0.5 * maxh, maxw, maxh);
   cairo_clip(cr);
-
-  cairo_scale(cr, zoom_scale, zoom_scale);
-
   const double back_scale = (buf_scale == 0 ? 1.0 : backbuf_scale / buf_scale) * (1<<closeup) / ppd;
   const double trans_x = (offset_x - zoom_x) * processed_width * buf_scale - 0.5 * buf_width;
   const double trans_y = (offset_y - zoom_y) * processed_height * buf_scale - 0.5 * buf_height;
 
-  if(dev->preview_pipe->output_imgid == dev->image_storage.id
+  if(pp->output_imgid == dev->image_storage.id
      && (port->pipe->output_imgid != dev->image_storage.id
          || fabsf(backbuf_scale / buf_scale - 1.0f) > .09f
          || floor(maxw / 2 / back_scale) - 1 > MIN(- trans_x, trans_x + buf_width)
          || floor(maxh / 2 / back_scale) - 1 > MIN(- trans_y, trans_y + buf_height))
      && (port == &dev->full || port == &dev->preview2))
   {
+    port->pipe->changed |= DT_DEV_PIPE_ZOOMED;
     if(port->pipe->status == DT_DEV_PIXELPIPE_VALID)
       port->pipe->status = DT_DEV_PIXELPIPE_DIRTY;
 
     // draw preview
-    float wd = processed_width * dev->preview_pipe->processed_width / MAX(1, dev->full.pipe->processed_width);
-    float ht = processed_height * dev->preview_pipe->processed_width / MAX(1, dev->full.pipe->processed_width);
+    const float wd = processed_width * pp->processed_width / MAX(1, dev->full.pipe->processed_width);
+    const float ht = processed_height * pp->processed_width / MAX(1, dev->full.pipe->processed_width);
 
-    cairo_surface_t *preview = dt_view_create_surface(dev->preview_pipe->backbuf,
-                                                      dev->preview_pipe->backbuf_width,
-                                                      dev->preview_pipe->backbuf_height);
-    cairo_set_source_surface(cr, preview, (preview_x - zoom_x) * wd - 0.5 * dev->preview_pipe->backbuf_width,
-                                          (preview_y - zoom_y) * ht - 0.5 * dev->preview_pipe->backbuf_height);
+    cairo_save(cr);
+    cairo_scale(cr, zoom_scale, zoom_scale);
+    _match_rotation(cr, pts + 6, (preview_x - zoom_x) * wd, (preview_y - zoom_y) * ht, 0, 0);
+    cairo_surface_t *preview = dt_view_create_surface(pp->backbuf, pp->backbuf_width, pp->backbuf_height);
+    cairo_set_source_surface(cr, preview, -0.5 * pp->backbuf_width, -0.5 * pp->backbuf_height);
     cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_FAST);
     cairo_paint(cr);
+    cairo_surface_destroy(preview);
+    cairo_restore(cr);
 
     dt_print_pipe(DT_DEBUG_EXPOSE,
         "  painting",
-         dev->preview_pipe, NULL, DT_DEVICE_NONE, NULL, NULL,
+         pp, NULL, DT_DEVICE_NONE, NULL, NULL,
          "size %4lux%-4lu processed %4.0fx%-4.0f "
          "buf %4dx%-4d scale=%.3f "
          "zoom (x=%6.2f y=%6.2f) -> offset (x=%+.3f y=%+.3f)",
          width, height, wd, ht,
-         dev->preview_pipe->backbuf_width, dev->preview_pipe->backbuf_height, zoom_scale,
-         dev->preview_pipe->backbuf_zoom_x, dev->preview_pipe->backbuf_zoom_y,
+         pp->backbuf_width, pp->backbuf_height, zoom_scale,
+         pp->backbuf_zoom_pos[0], pp->backbuf_zoom_pos[1],
          preview_x, preview_y);
-    cairo_surface_destroy(preview);
   }
 
-  dt_pthread_mutex_unlock(&dev->preview_pipe->backbuf_mutex);
+  dt_pthread_mutex_unlock(&pp->backbuf_mutex);
 
   if(port->pipe->output_imgid == dev->image_storage.id
-     || dev->preview_pipe->output_imgid != dev->image_storage.id)
+     || pp->output_imgid != dev->image_storage.id)
   {
     dt_print_pipe(DT_DEBUG_EXPOSE,
         "  painting",
@@ -1825,10 +1856,11 @@ void dt_view_paint_surface(cairo_t *cr,
          "zoom (x=%6.2f y=%6.2f) -> offset (x=%+.3f y=%+.3f)",
          width, height, processed_width, processed_height,
          buf_width, buf_height, buf_scale,
-         buf_zoom_x, buf_zoom_y,
+         buf_zoom_pos[0], buf_zoom_pos[1],
          offset_x, offset_y);
-    cairo_scale(cr, back_scale / zoom_scale, back_scale / zoom_scale);
-    cairo_translate(cr, trans_x, trans_y);
+
+    cairo_scale(cr, back_scale, back_scale);
+    _match_rotation(cr, pts, trans_x, trans_y, buf_width, buf_height);
     cairo_surface_t *surface = dt_view_create_surface(buf, buf_width, buf_height);
     cairo_set_source_surface(cr, surface, 0, 0);
     cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_FAST);
@@ -1863,7 +1895,7 @@ dt_view_context_t dt_view_get_context_hash(void)
   int closeup;
   float zoom_x, zoom_y;
   dt_dev_get_viewport_params(&dev->full, &zoom, &closeup, &zoom_x, &zoom_y);
-  const float zoom_scale = dt_dev_get_zoom_scale(&dev->full, zoom, 1<<closeup, 1);
+  const float zoom_scale = dt_dev_get_zoom_scale(&dev->full, zoom, 1<<closeup, TRUE);
 
   // calculate a hash on view parameters. Use flt_prec here to avoid different hashes
   // for irrelevant variations for the zooms.
